// Compiled by ClojureScript 1.7.145 {:static-fns true, :optimize-constants true}
goog.provide('om_tools.dom');
goog.require('cljs.core');
goog.require('clojure.string');
goog.require('om.dom');
/**
 * Converts kebab-case to camelCase
 */
om_tools.dom.camel_case = (function om_tools$dom$camel_case(s){
return clojure.string.replace(s,/-(\w)/,cljs.core.comp.cljs$core$IFn$_invoke$arity$2(clojure.string.upper_case,cljs.core.second));
});
/**
 * Converts attributes that are kebab-case and should be camelCase
 */
om_tools.dom.opt_key_case = (function om_tools$dom$opt_key_case(attr){
if(cljs.core.truth_((function (){var or__4512__auto__ = (cljs.core.count(attr) < (5));
if(or__4512__auto__){
return or__4512__auto__;
} else {
var G__21904 = cljs.core.subs.cljs$core$IFn$_invoke$arity$3(attr,(0),(5));
switch (G__21904) {
case "data-":
case "aria-":
return true;

break;
default:
return false;

}
}
})())){
return attr;
} else {
return om_tools.dom.camel_case(attr);
}
});
/**
 * Converts aliased attributes
 */
om_tools.dom.opt_key_alias = (function om_tools$dom$opt_key_alias(opt){
var G__21907 = (((opt instanceof cljs.core.Keyword))?opt.fqn:null);
switch (G__21907) {
case "class":
return cljs.core.cst$kw$className;

break;
case "for":
return cljs.core.cst$kw$htmlFor;

break;
default:
return opt;

}
});
/**
 * Returns potentially formatted name for DOM element attribute.
 * Converts kebab-case to camelCase.
 */
om_tools.dom.format_opt_key = (function om_tools$dom$format_opt_key(opt_key){
return cljs.core.keyword.cljs$core$IFn$_invoke$arity$1(om_tools.dom.opt_key_case(cljs.core.name(om_tools.dom.opt_key_alias(opt_key))));
});
om_tools.dom.format_opts;
/**
 * Returns potentially modified value for DOM element attribute.
 * Recursively formats map values (ie :style attribute)
 */
om_tools.dom.format_opt_val = (function om_tools$dom$format_opt_val(opt_val){
if(cljs.core.map_QMARK_(opt_val)){
return (om_tools.dom.format_opts.cljs$core$IFn$_invoke$arity$1 ? om_tools.dom.format_opts.cljs$core$IFn$_invoke$arity$1(opt_val) : om_tools.dom.format_opts.call(null,opt_val));
} else {
return opt_val;

}
});
/**
 * Returns JavaScript object for React DOM attributes from opts map
 */
om_tools.dom.format_opts = (function om_tools$dom$format_opts(opts){
if(cljs.core.map_QMARK_(opts)){
return cljs.core.clj__GT_js(cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentArrayMap.EMPTY,cljs.core.map.cljs$core$IFn$_invoke$arity$2((function (p__21911){
var vec__21912 = p__21911;
var k = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__21912,(0),null);
var v = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__21912,(1),null);
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [om_tools.dom.format_opt_key(k),om_tools.dom.format_opt_val(v)], null);
}),opts)));
} else {
return opts;
}
});
om_tools.dom.possible_coll_QMARK_ = (function om_tools$dom$possible_coll_QMARK_(form){
return (cljs.core.coll_QMARK_(form)) || ((form instanceof cljs.core.Symbol)) || (cljs.core.list_QMARK_(form));
});
om_tools.dom.valid_element_QMARK_ = (function om_tools$dom$valid_element_QMARK_(x){
return (function (){var or__4512__auto__ = React.isValidElement;
if(cljs.core.truth_(or__4512__auto__)){
return or__4512__auto__;
} else {
return React.isValidComponent;
}
})().call(null,x);
});
om_tools.dom.js_opts_QMARK_ = (function om_tools$dom$js_opts_QMARK_(x){
return (cljs.core.object_QMARK_(x)) && (!(om_tools.dom.valid_element_QMARK_(x)));
});
/**
 * Returns a vector of [opts children] for from first and second
 *   argument given to DOM function
 */
om_tools.dom.element_args = (function om_tools$dom$element_args(opts,children){
if((opts == null)){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [null,children], null);
} else {
if(cljs.core.map_QMARK_(opts)){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [om_tools.dom.format_opts(opts),children], null);
} else {
if(cljs.core.truth_(om_tools.dom.js_opts_QMARK_(opts))){
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [opts,children], null);
} else {
return new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [null,cljs.core.cons(opts,children)], null);

}
}
}
});
om_tools.dom.element = (function om_tools$dom$element(ctor,opts,children){
var vec__21914 = om_tools.dom.element_args(opts,children);
var opts__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__21914,(0),null);
var children__$1 = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__21914,(1),null);
return cljs.core.apply.cljs$core$IFn$_invoke$arity$2(ctor,cljs.core.flatten(cljs.core.cons(opts__$1,children__$1)));
});
om_tools.dom.a = (function om_tools$dom$a(var_args){
var args21915 = [];
var len__5570__auto___22540 = arguments.length;
var i__5571__auto___22541 = (0);
while(true){
if((i__5571__auto___22541 < len__5570__auto___22540)){
args21915.push((arguments[i__5571__auto___22541]));

var G__22542 = (i__5571__auto___22541 + (1));
i__5571__auto___22541 = G__22542;
continue;
} else {
}
break;
}

var G__21919 = args21915.length;
switch (G__21919) {
case 0:
return om_tools.dom.a.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21915.slice((1)),(0)));
return om_tools.dom.a.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.a.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.a,null,null);
});

om_tools.dom.a.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.a,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.a.cljs$lang$applyTo = (function (seq21916){
var G__21917 = cljs.core.first(seq21916);
var seq21916__$1 = cljs.core.next(seq21916);
return om_tools.dom.a.cljs$core$IFn$_invoke$arity$variadic(G__21917,seq21916__$1);
});

om_tools.dom.a.cljs$lang$maxFixedArity = (1);

om_tools.dom.abbr = (function om_tools$dom$abbr(var_args){
var args21920 = [];
var len__5570__auto___22544 = arguments.length;
var i__5571__auto___22545 = (0);
while(true){
if((i__5571__auto___22545 < len__5570__auto___22544)){
args21920.push((arguments[i__5571__auto___22545]));

var G__22546 = (i__5571__auto___22545 + (1));
i__5571__auto___22545 = G__22546;
continue;
} else {
}
break;
}

var G__21924 = args21920.length;
switch (G__21924) {
case 0:
return om_tools.dom.abbr.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21920.slice((1)),(0)));
return om_tools.dom.abbr.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.abbr.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.abbr,null,null);
});

om_tools.dom.abbr.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.abbr,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.abbr.cljs$lang$applyTo = (function (seq21921){
var G__21922 = cljs.core.first(seq21921);
var seq21921__$1 = cljs.core.next(seq21921);
return om_tools.dom.abbr.cljs$core$IFn$_invoke$arity$variadic(G__21922,seq21921__$1);
});

om_tools.dom.abbr.cljs$lang$maxFixedArity = (1);

om_tools.dom.address = (function om_tools$dom$address(var_args){
var args21925 = [];
var len__5570__auto___22548 = arguments.length;
var i__5571__auto___22549 = (0);
while(true){
if((i__5571__auto___22549 < len__5570__auto___22548)){
args21925.push((arguments[i__5571__auto___22549]));

var G__22550 = (i__5571__auto___22549 + (1));
i__5571__auto___22549 = G__22550;
continue;
} else {
}
break;
}

var G__21929 = args21925.length;
switch (G__21929) {
case 0:
return om_tools.dom.address.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21925.slice((1)),(0)));
return om_tools.dom.address.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.address.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.address,null,null);
});

om_tools.dom.address.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.address,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.address.cljs$lang$applyTo = (function (seq21926){
var G__21927 = cljs.core.first(seq21926);
var seq21926__$1 = cljs.core.next(seq21926);
return om_tools.dom.address.cljs$core$IFn$_invoke$arity$variadic(G__21927,seq21926__$1);
});

om_tools.dom.address.cljs$lang$maxFixedArity = (1);

om_tools.dom.area = (function om_tools$dom$area(var_args){
var args21930 = [];
var len__5570__auto___22552 = arguments.length;
var i__5571__auto___22553 = (0);
while(true){
if((i__5571__auto___22553 < len__5570__auto___22552)){
args21930.push((arguments[i__5571__auto___22553]));

var G__22554 = (i__5571__auto___22553 + (1));
i__5571__auto___22553 = G__22554;
continue;
} else {
}
break;
}

var G__21934 = args21930.length;
switch (G__21934) {
case 0:
return om_tools.dom.area.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21930.slice((1)),(0)));
return om_tools.dom.area.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.area.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.area,null,null);
});

om_tools.dom.area.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.area,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.area.cljs$lang$applyTo = (function (seq21931){
var G__21932 = cljs.core.first(seq21931);
var seq21931__$1 = cljs.core.next(seq21931);
return om_tools.dom.area.cljs$core$IFn$_invoke$arity$variadic(G__21932,seq21931__$1);
});

om_tools.dom.area.cljs$lang$maxFixedArity = (1);

om_tools.dom.article = (function om_tools$dom$article(var_args){
var args21935 = [];
var len__5570__auto___22556 = arguments.length;
var i__5571__auto___22557 = (0);
while(true){
if((i__5571__auto___22557 < len__5570__auto___22556)){
args21935.push((arguments[i__5571__auto___22557]));

var G__22558 = (i__5571__auto___22557 + (1));
i__5571__auto___22557 = G__22558;
continue;
} else {
}
break;
}

var G__21939 = args21935.length;
switch (G__21939) {
case 0:
return om_tools.dom.article.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21935.slice((1)),(0)));
return om_tools.dom.article.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.article.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.article,null,null);
});

om_tools.dom.article.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.article,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.article.cljs$lang$applyTo = (function (seq21936){
var G__21937 = cljs.core.first(seq21936);
var seq21936__$1 = cljs.core.next(seq21936);
return om_tools.dom.article.cljs$core$IFn$_invoke$arity$variadic(G__21937,seq21936__$1);
});

om_tools.dom.article.cljs$lang$maxFixedArity = (1);

om_tools.dom.aside = (function om_tools$dom$aside(var_args){
var args21940 = [];
var len__5570__auto___22560 = arguments.length;
var i__5571__auto___22561 = (0);
while(true){
if((i__5571__auto___22561 < len__5570__auto___22560)){
args21940.push((arguments[i__5571__auto___22561]));

var G__22562 = (i__5571__auto___22561 + (1));
i__5571__auto___22561 = G__22562;
continue;
} else {
}
break;
}

var G__21944 = args21940.length;
switch (G__21944) {
case 0:
return om_tools.dom.aside.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21940.slice((1)),(0)));
return om_tools.dom.aside.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.aside.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.aside,null,null);
});

om_tools.dom.aside.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.aside,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.aside.cljs$lang$applyTo = (function (seq21941){
var G__21942 = cljs.core.first(seq21941);
var seq21941__$1 = cljs.core.next(seq21941);
return om_tools.dom.aside.cljs$core$IFn$_invoke$arity$variadic(G__21942,seq21941__$1);
});

om_tools.dom.aside.cljs$lang$maxFixedArity = (1);

om_tools.dom.audio = (function om_tools$dom$audio(var_args){
var args21945 = [];
var len__5570__auto___22564 = arguments.length;
var i__5571__auto___22565 = (0);
while(true){
if((i__5571__auto___22565 < len__5570__auto___22564)){
args21945.push((arguments[i__5571__auto___22565]));

var G__22566 = (i__5571__auto___22565 + (1));
i__5571__auto___22565 = G__22566;
continue;
} else {
}
break;
}

var G__21949 = args21945.length;
switch (G__21949) {
case 0:
return om_tools.dom.audio.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21945.slice((1)),(0)));
return om_tools.dom.audio.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.audio.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.audio,null,null);
});

om_tools.dom.audio.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.audio,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.audio.cljs$lang$applyTo = (function (seq21946){
var G__21947 = cljs.core.first(seq21946);
var seq21946__$1 = cljs.core.next(seq21946);
return om_tools.dom.audio.cljs$core$IFn$_invoke$arity$variadic(G__21947,seq21946__$1);
});

om_tools.dom.audio.cljs$lang$maxFixedArity = (1);

om_tools.dom.b = (function om_tools$dom$b(var_args){
var args21950 = [];
var len__5570__auto___22568 = arguments.length;
var i__5571__auto___22569 = (0);
while(true){
if((i__5571__auto___22569 < len__5570__auto___22568)){
args21950.push((arguments[i__5571__auto___22569]));

var G__22570 = (i__5571__auto___22569 + (1));
i__5571__auto___22569 = G__22570;
continue;
} else {
}
break;
}

var G__21954 = args21950.length;
switch (G__21954) {
case 0:
return om_tools.dom.b.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21950.slice((1)),(0)));
return om_tools.dom.b.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.b.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.b,null,null);
});

om_tools.dom.b.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.b,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.b.cljs$lang$applyTo = (function (seq21951){
var G__21952 = cljs.core.first(seq21951);
var seq21951__$1 = cljs.core.next(seq21951);
return om_tools.dom.b.cljs$core$IFn$_invoke$arity$variadic(G__21952,seq21951__$1);
});

om_tools.dom.b.cljs$lang$maxFixedArity = (1);

om_tools.dom.base = (function om_tools$dom$base(var_args){
var args21955 = [];
var len__5570__auto___22572 = arguments.length;
var i__5571__auto___22573 = (0);
while(true){
if((i__5571__auto___22573 < len__5570__auto___22572)){
args21955.push((arguments[i__5571__auto___22573]));

var G__22574 = (i__5571__auto___22573 + (1));
i__5571__auto___22573 = G__22574;
continue;
} else {
}
break;
}

var G__21959 = args21955.length;
switch (G__21959) {
case 0:
return om_tools.dom.base.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21955.slice((1)),(0)));
return om_tools.dom.base.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.base.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.base,null,null);
});

om_tools.dom.base.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.base,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.base.cljs$lang$applyTo = (function (seq21956){
var G__21957 = cljs.core.first(seq21956);
var seq21956__$1 = cljs.core.next(seq21956);
return om_tools.dom.base.cljs$core$IFn$_invoke$arity$variadic(G__21957,seq21956__$1);
});

om_tools.dom.base.cljs$lang$maxFixedArity = (1);

om_tools.dom.bdi = (function om_tools$dom$bdi(var_args){
var args21960 = [];
var len__5570__auto___22576 = arguments.length;
var i__5571__auto___22577 = (0);
while(true){
if((i__5571__auto___22577 < len__5570__auto___22576)){
args21960.push((arguments[i__5571__auto___22577]));

var G__22578 = (i__5571__auto___22577 + (1));
i__5571__auto___22577 = G__22578;
continue;
} else {
}
break;
}

var G__21964 = args21960.length;
switch (G__21964) {
case 0:
return om_tools.dom.bdi.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21960.slice((1)),(0)));
return om_tools.dom.bdi.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.bdi.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.bdi,null,null);
});

om_tools.dom.bdi.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.bdi,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.bdi.cljs$lang$applyTo = (function (seq21961){
var G__21962 = cljs.core.first(seq21961);
var seq21961__$1 = cljs.core.next(seq21961);
return om_tools.dom.bdi.cljs$core$IFn$_invoke$arity$variadic(G__21962,seq21961__$1);
});

om_tools.dom.bdi.cljs$lang$maxFixedArity = (1);

om_tools.dom.bdo = (function om_tools$dom$bdo(var_args){
var args21965 = [];
var len__5570__auto___22580 = arguments.length;
var i__5571__auto___22581 = (0);
while(true){
if((i__5571__auto___22581 < len__5570__auto___22580)){
args21965.push((arguments[i__5571__auto___22581]));

var G__22582 = (i__5571__auto___22581 + (1));
i__5571__auto___22581 = G__22582;
continue;
} else {
}
break;
}

var G__21969 = args21965.length;
switch (G__21969) {
case 0:
return om_tools.dom.bdo.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21965.slice((1)),(0)));
return om_tools.dom.bdo.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.bdo.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.bdo,null,null);
});

om_tools.dom.bdo.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.bdo,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.bdo.cljs$lang$applyTo = (function (seq21966){
var G__21967 = cljs.core.first(seq21966);
var seq21966__$1 = cljs.core.next(seq21966);
return om_tools.dom.bdo.cljs$core$IFn$_invoke$arity$variadic(G__21967,seq21966__$1);
});

om_tools.dom.bdo.cljs$lang$maxFixedArity = (1);

om_tools.dom.big = (function om_tools$dom$big(var_args){
var args21970 = [];
var len__5570__auto___22584 = arguments.length;
var i__5571__auto___22585 = (0);
while(true){
if((i__5571__auto___22585 < len__5570__auto___22584)){
args21970.push((arguments[i__5571__auto___22585]));

var G__22586 = (i__5571__auto___22585 + (1));
i__5571__auto___22585 = G__22586;
continue;
} else {
}
break;
}

var G__21974 = args21970.length;
switch (G__21974) {
case 0:
return om_tools.dom.big.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21970.slice((1)),(0)));
return om_tools.dom.big.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.big.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.big,null,null);
});

om_tools.dom.big.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.big,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.big.cljs$lang$applyTo = (function (seq21971){
var G__21972 = cljs.core.first(seq21971);
var seq21971__$1 = cljs.core.next(seq21971);
return om_tools.dom.big.cljs$core$IFn$_invoke$arity$variadic(G__21972,seq21971__$1);
});

om_tools.dom.big.cljs$lang$maxFixedArity = (1);

om_tools.dom.blockquote = (function om_tools$dom$blockquote(var_args){
var args21975 = [];
var len__5570__auto___22588 = arguments.length;
var i__5571__auto___22589 = (0);
while(true){
if((i__5571__auto___22589 < len__5570__auto___22588)){
args21975.push((arguments[i__5571__auto___22589]));

var G__22590 = (i__5571__auto___22589 + (1));
i__5571__auto___22589 = G__22590;
continue;
} else {
}
break;
}

var G__21979 = args21975.length;
switch (G__21979) {
case 0:
return om_tools.dom.blockquote.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21975.slice((1)),(0)));
return om_tools.dom.blockquote.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.blockquote.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.blockquote,null,null);
});

om_tools.dom.blockquote.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.blockquote,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.blockquote.cljs$lang$applyTo = (function (seq21976){
var G__21977 = cljs.core.first(seq21976);
var seq21976__$1 = cljs.core.next(seq21976);
return om_tools.dom.blockquote.cljs$core$IFn$_invoke$arity$variadic(G__21977,seq21976__$1);
});

om_tools.dom.blockquote.cljs$lang$maxFixedArity = (1);

om_tools.dom.body = (function om_tools$dom$body(var_args){
var args21980 = [];
var len__5570__auto___22592 = arguments.length;
var i__5571__auto___22593 = (0);
while(true){
if((i__5571__auto___22593 < len__5570__auto___22592)){
args21980.push((arguments[i__5571__auto___22593]));

var G__22594 = (i__5571__auto___22593 + (1));
i__5571__auto___22593 = G__22594;
continue;
} else {
}
break;
}

var G__21984 = args21980.length;
switch (G__21984) {
case 0:
return om_tools.dom.body.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21980.slice((1)),(0)));
return om_tools.dom.body.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.body.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.body,null,null);
});

om_tools.dom.body.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.body,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.body.cljs$lang$applyTo = (function (seq21981){
var G__21982 = cljs.core.first(seq21981);
var seq21981__$1 = cljs.core.next(seq21981);
return om_tools.dom.body.cljs$core$IFn$_invoke$arity$variadic(G__21982,seq21981__$1);
});

om_tools.dom.body.cljs$lang$maxFixedArity = (1);

om_tools.dom.br = (function om_tools$dom$br(var_args){
var args21985 = [];
var len__5570__auto___22596 = arguments.length;
var i__5571__auto___22597 = (0);
while(true){
if((i__5571__auto___22597 < len__5570__auto___22596)){
args21985.push((arguments[i__5571__auto___22597]));

var G__22598 = (i__5571__auto___22597 + (1));
i__5571__auto___22597 = G__22598;
continue;
} else {
}
break;
}

var G__21989 = args21985.length;
switch (G__21989) {
case 0:
return om_tools.dom.br.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21985.slice((1)),(0)));
return om_tools.dom.br.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.br.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.br,null,null);
});

om_tools.dom.br.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.br,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.br.cljs$lang$applyTo = (function (seq21986){
var G__21987 = cljs.core.first(seq21986);
var seq21986__$1 = cljs.core.next(seq21986);
return om_tools.dom.br.cljs$core$IFn$_invoke$arity$variadic(G__21987,seq21986__$1);
});

om_tools.dom.br.cljs$lang$maxFixedArity = (1);

om_tools.dom.button = (function om_tools$dom$button(var_args){
var args21990 = [];
var len__5570__auto___22600 = arguments.length;
var i__5571__auto___22601 = (0);
while(true){
if((i__5571__auto___22601 < len__5570__auto___22600)){
args21990.push((arguments[i__5571__auto___22601]));

var G__22602 = (i__5571__auto___22601 + (1));
i__5571__auto___22601 = G__22602;
continue;
} else {
}
break;
}

var G__21994 = args21990.length;
switch (G__21994) {
case 0:
return om_tools.dom.button.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21990.slice((1)),(0)));
return om_tools.dom.button.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.button.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.button,null,null);
});

om_tools.dom.button.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.button,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.button.cljs$lang$applyTo = (function (seq21991){
var G__21992 = cljs.core.first(seq21991);
var seq21991__$1 = cljs.core.next(seq21991);
return om_tools.dom.button.cljs$core$IFn$_invoke$arity$variadic(G__21992,seq21991__$1);
});

om_tools.dom.button.cljs$lang$maxFixedArity = (1);

om_tools.dom.canvas = (function om_tools$dom$canvas(var_args){
var args21995 = [];
var len__5570__auto___22604 = arguments.length;
var i__5571__auto___22605 = (0);
while(true){
if((i__5571__auto___22605 < len__5570__auto___22604)){
args21995.push((arguments[i__5571__auto___22605]));

var G__22606 = (i__5571__auto___22605 + (1));
i__5571__auto___22605 = G__22606;
continue;
} else {
}
break;
}

var G__21999 = args21995.length;
switch (G__21999) {
case 0:
return om_tools.dom.canvas.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args21995.slice((1)),(0)));
return om_tools.dom.canvas.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.canvas.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.canvas,null,null);
});

om_tools.dom.canvas.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.canvas,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.canvas.cljs$lang$applyTo = (function (seq21996){
var G__21997 = cljs.core.first(seq21996);
var seq21996__$1 = cljs.core.next(seq21996);
return om_tools.dom.canvas.cljs$core$IFn$_invoke$arity$variadic(G__21997,seq21996__$1);
});

om_tools.dom.canvas.cljs$lang$maxFixedArity = (1);

om_tools.dom.caption = (function om_tools$dom$caption(var_args){
var args22000 = [];
var len__5570__auto___22608 = arguments.length;
var i__5571__auto___22609 = (0);
while(true){
if((i__5571__auto___22609 < len__5570__auto___22608)){
args22000.push((arguments[i__5571__auto___22609]));

var G__22610 = (i__5571__auto___22609 + (1));
i__5571__auto___22609 = G__22610;
continue;
} else {
}
break;
}

var G__22004 = args22000.length;
switch (G__22004) {
case 0:
return om_tools.dom.caption.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22000.slice((1)),(0)));
return om_tools.dom.caption.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.caption.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.caption,null,null);
});

om_tools.dom.caption.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.caption,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.caption.cljs$lang$applyTo = (function (seq22001){
var G__22002 = cljs.core.first(seq22001);
var seq22001__$1 = cljs.core.next(seq22001);
return om_tools.dom.caption.cljs$core$IFn$_invoke$arity$variadic(G__22002,seq22001__$1);
});

om_tools.dom.caption.cljs$lang$maxFixedArity = (1);

om_tools.dom.cite = (function om_tools$dom$cite(var_args){
var args22005 = [];
var len__5570__auto___22612 = arguments.length;
var i__5571__auto___22613 = (0);
while(true){
if((i__5571__auto___22613 < len__5570__auto___22612)){
args22005.push((arguments[i__5571__auto___22613]));

var G__22614 = (i__5571__auto___22613 + (1));
i__5571__auto___22613 = G__22614;
continue;
} else {
}
break;
}

var G__22009 = args22005.length;
switch (G__22009) {
case 0:
return om_tools.dom.cite.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22005.slice((1)),(0)));
return om_tools.dom.cite.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.cite.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.cite,null,null);
});

om_tools.dom.cite.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.cite,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.cite.cljs$lang$applyTo = (function (seq22006){
var G__22007 = cljs.core.first(seq22006);
var seq22006__$1 = cljs.core.next(seq22006);
return om_tools.dom.cite.cljs$core$IFn$_invoke$arity$variadic(G__22007,seq22006__$1);
});

om_tools.dom.cite.cljs$lang$maxFixedArity = (1);

om_tools.dom.code = (function om_tools$dom$code(var_args){
var args22010 = [];
var len__5570__auto___22616 = arguments.length;
var i__5571__auto___22617 = (0);
while(true){
if((i__5571__auto___22617 < len__5570__auto___22616)){
args22010.push((arguments[i__5571__auto___22617]));

var G__22618 = (i__5571__auto___22617 + (1));
i__5571__auto___22617 = G__22618;
continue;
} else {
}
break;
}

var G__22014 = args22010.length;
switch (G__22014) {
case 0:
return om_tools.dom.code.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22010.slice((1)),(0)));
return om_tools.dom.code.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.code.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.code,null,null);
});

om_tools.dom.code.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.code,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.code.cljs$lang$applyTo = (function (seq22011){
var G__22012 = cljs.core.first(seq22011);
var seq22011__$1 = cljs.core.next(seq22011);
return om_tools.dom.code.cljs$core$IFn$_invoke$arity$variadic(G__22012,seq22011__$1);
});

om_tools.dom.code.cljs$lang$maxFixedArity = (1);

om_tools.dom.col = (function om_tools$dom$col(var_args){
var args22015 = [];
var len__5570__auto___22620 = arguments.length;
var i__5571__auto___22621 = (0);
while(true){
if((i__5571__auto___22621 < len__5570__auto___22620)){
args22015.push((arguments[i__5571__auto___22621]));

var G__22622 = (i__5571__auto___22621 + (1));
i__5571__auto___22621 = G__22622;
continue;
} else {
}
break;
}

var G__22019 = args22015.length;
switch (G__22019) {
case 0:
return om_tools.dom.col.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22015.slice((1)),(0)));
return om_tools.dom.col.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.col.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.col,null,null);
});

om_tools.dom.col.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.col,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.col.cljs$lang$applyTo = (function (seq22016){
var G__22017 = cljs.core.first(seq22016);
var seq22016__$1 = cljs.core.next(seq22016);
return om_tools.dom.col.cljs$core$IFn$_invoke$arity$variadic(G__22017,seq22016__$1);
});

om_tools.dom.col.cljs$lang$maxFixedArity = (1);

om_tools.dom.colgroup = (function om_tools$dom$colgroup(var_args){
var args22020 = [];
var len__5570__auto___22624 = arguments.length;
var i__5571__auto___22625 = (0);
while(true){
if((i__5571__auto___22625 < len__5570__auto___22624)){
args22020.push((arguments[i__5571__auto___22625]));

var G__22626 = (i__5571__auto___22625 + (1));
i__5571__auto___22625 = G__22626;
continue;
} else {
}
break;
}

var G__22024 = args22020.length;
switch (G__22024) {
case 0:
return om_tools.dom.colgroup.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22020.slice((1)),(0)));
return om_tools.dom.colgroup.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.colgroup.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.colgroup,null,null);
});

om_tools.dom.colgroup.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.colgroup,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.colgroup.cljs$lang$applyTo = (function (seq22021){
var G__22022 = cljs.core.first(seq22021);
var seq22021__$1 = cljs.core.next(seq22021);
return om_tools.dom.colgroup.cljs$core$IFn$_invoke$arity$variadic(G__22022,seq22021__$1);
});

om_tools.dom.colgroup.cljs$lang$maxFixedArity = (1);

om_tools.dom.data = (function om_tools$dom$data(var_args){
var args22025 = [];
var len__5570__auto___22628 = arguments.length;
var i__5571__auto___22629 = (0);
while(true){
if((i__5571__auto___22629 < len__5570__auto___22628)){
args22025.push((arguments[i__5571__auto___22629]));

var G__22630 = (i__5571__auto___22629 + (1));
i__5571__auto___22629 = G__22630;
continue;
} else {
}
break;
}

var G__22029 = args22025.length;
switch (G__22029) {
case 0:
return om_tools.dom.data.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22025.slice((1)),(0)));
return om_tools.dom.data.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.data.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.data,null,null);
});

om_tools.dom.data.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.data,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.data.cljs$lang$applyTo = (function (seq22026){
var G__22027 = cljs.core.first(seq22026);
var seq22026__$1 = cljs.core.next(seq22026);
return om_tools.dom.data.cljs$core$IFn$_invoke$arity$variadic(G__22027,seq22026__$1);
});

om_tools.dom.data.cljs$lang$maxFixedArity = (1);

om_tools.dom.datalist = (function om_tools$dom$datalist(var_args){
var args22030 = [];
var len__5570__auto___22632 = arguments.length;
var i__5571__auto___22633 = (0);
while(true){
if((i__5571__auto___22633 < len__5570__auto___22632)){
args22030.push((arguments[i__5571__auto___22633]));

var G__22634 = (i__5571__auto___22633 + (1));
i__5571__auto___22633 = G__22634;
continue;
} else {
}
break;
}

var G__22034 = args22030.length;
switch (G__22034) {
case 0:
return om_tools.dom.datalist.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22030.slice((1)),(0)));
return om_tools.dom.datalist.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.datalist.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.datalist,null,null);
});

om_tools.dom.datalist.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.datalist,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.datalist.cljs$lang$applyTo = (function (seq22031){
var G__22032 = cljs.core.first(seq22031);
var seq22031__$1 = cljs.core.next(seq22031);
return om_tools.dom.datalist.cljs$core$IFn$_invoke$arity$variadic(G__22032,seq22031__$1);
});

om_tools.dom.datalist.cljs$lang$maxFixedArity = (1);

om_tools.dom.dd = (function om_tools$dom$dd(var_args){
var args22035 = [];
var len__5570__auto___22636 = arguments.length;
var i__5571__auto___22637 = (0);
while(true){
if((i__5571__auto___22637 < len__5570__auto___22636)){
args22035.push((arguments[i__5571__auto___22637]));

var G__22638 = (i__5571__auto___22637 + (1));
i__5571__auto___22637 = G__22638;
continue;
} else {
}
break;
}

var G__22039 = args22035.length;
switch (G__22039) {
case 0:
return om_tools.dom.dd.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22035.slice((1)),(0)));
return om_tools.dom.dd.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.dd.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.dd,null,null);
});

om_tools.dom.dd.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.dd,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.dd.cljs$lang$applyTo = (function (seq22036){
var G__22037 = cljs.core.first(seq22036);
var seq22036__$1 = cljs.core.next(seq22036);
return om_tools.dom.dd.cljs$core$IFn$_invoke$arity$variadic(G__22037,seq22036__$1);
});

om_tools.dom.dd.cljs$lang$maxFixedArity = (1);

om_tools.dom.del = (function om_tools$dom$del(var_args){
var args22040 = [];
var len__5570__auto___22640 = arguments.length;
var i__5571__auto___22641 = (0);
while(true){
if((i__5571__auto___22641 < len__5570__auto___22640)){
args22040.push((arguments[i__5571__auto___22641]));

var G__22642 = (i__5571__auto___22641 + (1));
i__5571__auto___22641 = G__22642;
continue;
} else {
}
break;
}

var G__22044 = args22040.length;
switch (G__22044) {
case 0:
return om_tools.dom.del.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22040.slice((1)),(0)));
return om_tools.dom.del.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.del.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.del,null,null);
});

om_tools.dom.del.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.del,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.del.cljs$lang$applyTo = (function (seq22041){
var G__22042 = cljs.core.first(seq22041);
var seq22041__$1 = cljs.core.next(seq22041);
return om_tools.dom.del.cljs$core$IFn$_invoke$arity$variadic(G__22042,seq22041__$1);
});

om_tools.dom.del.cljs$lang$maxFixedArity = (1);

om_tools.dom.dfn = (function om_tools$dom$dfn(var_args){
var args22045 = [];
var len__5570__auto___22644 = arguments.length;
var i__5571__auto___22645 = (0);
while(true){
if((i__5571__auto___22645 < len__5570__auto___22644)){
args22045.push((arguments[i__5571__auto___22645]));

var G__22646 = (i__5571__auto___22645 + (1));
i__5571__auto___22645 = G__22646;
continue;
} else {
}
break;
}

var G__22049 = args22045.length;
switch (G__22049) {
case 0:
return om_tools.dom.dfn.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22045.slice((1)),(0)));
return om_tools.dom.dfn.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.dfn.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.dfn,null,null);
});

om_tools.dom.dfn.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.dfn,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.dfn.cljs$lang$applyTo = (function (seq22046){
var G__22047 = cljs.core.first(seq22046);
var seq22046__$1 = cljs.core.next(seq22046);
return om_tools.dom.dfn.cljs$core$IFn$_invoke$arity$variadic(G__22047,seq22046__$1);
});

om_tools.dom.dfn.cljs$lang$maxFixedArity = (1);

om_tools.dom.div = (function om_tools$dom$div(var_args){
var args22050 = [];
var len__5570__auto___22648 = arguments.length;
var i__5571__auto___22649 = (0);
while(true){
if((i__5571__auto___22649 < len__5570__auto___22648)){
args22050.push((arguments[i__5571__auto___22649]));

var G__22650 = (i__5571__auto___22649 + (1));
i__5571__auto___22649 = G__22650;
continue;
} else {
}
break;
}

var G__22054 = args22050.length;
switch (G__22054) {
case 0:
return om_tools.dom.div.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22050.slice((1)),(0)));
return om_tools.dom.div.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.div.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.div,null,null);
});

om_tools.dom.div.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.div,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.div.cljs$lang$applyTo = (function (seq22051){
var G__22052 = cljs.core.first(seq22051);
var seq22051__$1 = cljs.core.next(seq22051);
return om_tools.dom.div.cljs$core$IFn$_invoke$arity$variadic(G__22052,seq22051__$1);
});

om_tools.dom.div.cljs$lang$maxFixedArity = (1);

om_tools.dom.dl = (function om_tools$dom$dl(var_args){
var args22055 = [];
var len__5570__auto___22652 = arguments.length;
var i__5571__auto___22653 = (0);
while(true){
if((i__5571__auto___22653 < len__5570__auto___22652)){
args22055.push((arguments[i__5571__auto___22653]));

var G__22654 = (i__5571__auto___22653 + (1));
i__5571__auto___22653 = G__22654;
continue;
} else {
}
break;
}

var G__22059 = args22055.length;
switch (G__22059) {
case 0:
return om_tools.dom.dl.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22055.slice((1)),(0)));
return om_tools.dom.dl.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.dl.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.dl,null,null);
});

om_tools.dom.dl.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.dl,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.dl.cljs$lang$applyTo = (function (seq22056){
var G__22057 = cljs.core.first(seq22056);
var seq22056__$1 = cljs.core.next(seq22056);
return om_tools.dom.dl.cljs$core$IFn$_invoke$arity$variadic(G__22057,seq22056__$1);
});

om_tools.dom.dl.cljs$lang$maxFixedArity = (1);

om_tools.dom.dt = (function om_tools$dom$dt(var_args){
var args22060 = [];
var len__5570__auto___22656 = arguments.length;
var i__5571__auto___22657 = (0);
while(true){
if((i__5571__auto___22657 < len__5570__auto___22656)){
args22060.push((arguments[i__5571__auto___22657]));

var G__22658 = (i__5571__auto___22657 + (1));
i__5571__auto___22657 = G__22658;
continue;
} else {
}
break;
}

var G__22064 = args22060.length;
switch (G__22064) {
case 0:
return om_tools.dom.dt.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22060.slice((1)),(0)));
return om_tools.dom.dt.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.dt.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.dt,null,null);
});

om_tools.dom.dt.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.dt,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.dt.cljs$lang$applyTo = (function (seq22061){
var G__22062 = cljs.core.first(seq22061);
var seq22061__$1 = cljs.core.next(seq22061);
return om_tools.dom.dt.cljs$core$IFn$_invoke$arity$variadic(G__22062,seq22061__$1);
});

om_tools.dom.dt.cljs$lang$maxFixedArity = (1);

om_tools.dom.em = (function om_tools$dom$em(var_args){
var args22065 = [];
var len__5570__auto___22660 = arguments.length;
var i__5571__auto___22661 = (0);
while(true){
if((i__5571__auto___22661 < len__5570__auto___22660)){
args22065.push((arguments[i__5571__auto___22661]));

var G__22662 = (i__5571__auto___22661 + (1));
i__5571__auto___22661 = G__22662;
continue;
} else {
}
break;
}

var G__22069 = args22065.length;
switch (G__22069) {
case 0:
return om_tools.dom.em.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22065.slice((1)),(0)));
return om_tools.dom.em.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.em.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.em,null,null);
});

om_tools.dom.em.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.em,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.em.cljs$lang$applyTo = (function (seq22066){
var G__22067 = cljs.core.first(seq22066);
var seq22066__$1 = cljs.core.next(seq22066);
return om_tools.dom.em.cljs$core$IFn$_invoke$arity$variadic(G__22067,seq22066__$1);
});

om_tools.dom.em.cljs$lang$maxFixedArity = (1);

om_tools.dom.embed = (function om_tools$dom$embed(var_args){
var args22070 = [];
var len__5570__auto___22664 = arguments.length;
var i__5571__auto___22665 = (0);
while(true){
if((i__5571__auto___22665 < len__5570__auto___22664)){
args22070.push((arguments[i__5571__auto___22665]));

var G__22666 = (i__5571__auto___22665 + (1));
i__5571__auto___22665 = G__22666;
continue;
} else {
}
break;
}

var G__22074 = args22070.length;
switch (G__22074) {
case 0:
return om_tools.dom.embed.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22070.slice((1)),(0)));
return om_tools.dom.embed.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.embed.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.embed,null,null);
});

om_tools.dom.embed.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.embed,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.embed.cljs$lang$applyTo = (function (seq22071){
var G__22072 = cljs.core.first(seq22071);
var seq22071__$1 = cljs.core.next(seq22071);
return om_tools.dom.embed.cljs$core$IFn$_invoke$arity$variadic(G__22072,seq22071__$1);
});

om_tools.dom.embed.cljs$lang$maxFixedArity = (1);

om_tools.dom.fieldset = (function om_tools$dom$fieldset(var_args){
var args22080 = [];
var len__5570__auto___22668 = arguments.length;
var i__5571__auto___22669 = (0);
while(true){
if((i__5571__auto___22669 < len__5570__auto___22668)){
args22080.push((arguments[i__5571__auto___22669]));

var G__22670 = (i__5571__auto___22669 + (1));
i__5571__auto___22669 = G__22670;
continue;
} else {
}
break;
}

var G__22084 = args22080.length;
switch (G__22084) {
case 0:
return om_tools.dom.fieldset.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22080.slice((1)),(0)));
return om_tools.dom.fieldset.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.fieldset.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.fieldset,null,null);
});

om_tools.dom.fieldset.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.fieldset,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.fieldset.cljs$lang$applyTo = (function (seq22081){
var G__22082 = cljs.core.first(seq22081);
var seq22081__$1 = cljs.core.next(seq22081);
return om_tools.dom.fieldset.cljs$core$IFn$_invoke$arity$variadic(G__22082,seq22081__$1);
});

om_tools.dom.fieldset.cljs$lang$maxFixedArity = (1);

om_tools.dom.figcaption = (function om_tools$dom$figcaption(var_args){
var args22085 = [];
var len__5570__auto___22672 = arguments.length;
var i__5571__auto___22673 = (0);
while(true){
if((i__5571__auto___22673 < len__5570__auto___22672)){
args22085.push((arguments[i__5571__auto___22673]));

var G__22674 = (i__5571__auto___22673 + (1));
i__5571__auto___22673 = G__22674;
continue;
} else {
}
break;
}

var G__22089 = args22085.length;
switch (G__22089) {
case 0:
return om_tools.dom.figcaption.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22085.slice((1)),(0)));
return om_tools.dom.figcaption.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.figcaption.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.figcaption,null,null);
});

om_tools.dom.figcaption.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.figcaption,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.figcaption.cljs$lang$applyTo = (function (seq22086){
var G__22087 = cljs.core.first(seq22086);
var seq22086__$1 = cljs.core.next(seq22086);
return om_tools.dom.figcaption.cljs$core$IFn$_invoke$arity$variadic(G__22087,seq22086__$1);
});

om_tools.dom.figcaption.cljs$lang$maxFixedArity = (1);

om_tools.dom.figure = (function om_tools$dom$figure(var_args){
var args22090 = [];
var len__5570__auto___22676 = arguments.length;
var i__5571__auto___22677 = (0);
while(true){
if((i__5571__auto___22677 < len__5570__auto___22676)){
args22090.push((arguments[i__5571__auto___22677]));

var G__22678 = (i__5571__auto___22677 + (1));
i__5571__auto___22677 = G__22678;
continue;
} else {
}
break;
}

var G__22094 = args22090.length;
switch (G__22094) {
case 0:
return om_tools.dom.figure.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22090.slice((1)),(0)));
return om_tools.dom.figure.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.figure.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.figure,null,null);
});

om_tools.dom.figure.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.figure,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.figure.cljs$lang$applyTo = (function (seq22091){
var G__22092 = cljs.core.first(seq22091);
var seq22091__$1 = cljs.core.next(seq22091);
return om_tools.dom.figure.cljs$core$IFn$_invoke$arity$variadic(G__22092,seq22091__$1);
});

om_tools.dom.figure.cljs$lang$maxFixedArity = (1);

om_tools.dom.footer = (function om_tools$dom$footer(var_args){
var args22095 = [];
var len__5570__auto___22680 = arguments.length;
var i__5571__auto___22681 = (0);
while(true){
if((i__5571__auto___22681 < len__5570__auto___22680)){
args22095.push((arguments[i__5571__auto___22681]));

var G__22682 = (i__5571__auto___22681 + (1));
i__5571__auto___22681 = G__22682;
continue;
} else {
}
break;
}

var G__22099 = args22095.length;
switch (G__22099) {
case 0:
return om_tools.dom.footer.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22095.slice((1)),(0)));
return om_tools.dom.footer.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.footer.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.footer,null,null);
});

om_tools.dom.footer.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.footer,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.footer.cljs$lang$applyTo = (function (seq22096){
var G__22097 = cljs.core.first(seq22096);
var seq22096__$1 = cljs.core.next(seq22096);
return om_tools.dom.footer.cljs$core$IFn$_invoke$arity$variadic(G__22097,seq22096__$1);
});

om_tools.dom.footer.cljs$lang$maxFixedArity = (1);

om_tools.dom.form = (function om_tools$dom$form(var_args){
var args22100 = [];
var len__5570__auto___22684 = arguments.length;
var i__5571__auto___22685 = (0);
while(true){
if((i__5571__auto___22685 < len__5570__auto___22684)){
args22100.push((arguments[i__5571__auto___22685]));

var G__22686 = (i__5571__auto___22685 + (1));
i__5571__auto___22685 = G__22686;
continue;
} else {
}
break;
}

var G__22104 = args22100.length;
switch (G__22104) {
case 0:
return om_tools.dom.form.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22100.slice((1)),(0)));
return om_tools.dom.form.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.form.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.form,null,null);
});

om_tools.dom.form.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.form,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.form.cljs$lang$applyTo = (function (seq22101){
var G__22102 = cljs.core.first(seq22101);
var seq22101__$1 = cljs.core.next(seq22101);
return om_tools.dom.form.cljs$core$IFn$_invoke$arity$variadic(G__22102,seq22101__$1);
});

om_tools.dom.form.cljs$lang$maxFixedArity = (1);

om_tools.dom.h1 = (function om_tools$dom$h1(var_args){
var args22105 = [];
var len__5570__auto___22688 = arguments.length;
var i__5571__auto___22689 = (0);
while(true){
if((i__5571__auto___22689 < len__5570__auto___22688)){
args22105.push((arguments[i__5571__auto___22689]));

var G__22690 = (i__5571__auto___22689 + (1));
i__5571__auto___22689 = G__22690;
continue;
} else {
}
break;
}

var G__22109 = args22105.length;
switch (G__22109) {
case 0:
return om_tools.dom.h1.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22105.slice((1)),(0)));
return om_tools.dom.h1.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.h1.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.h1,null,null);
});

om_tools.dom.h1.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.h1,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.h1.cljs$lang$applyTo = (function (seq22106){
var G__22107 = cljs.core.first(seq22106);
var seq22106__$1 = cljs.core.next(seq22106);
return om_tools.dom.h1.cljs$core$IFn$_invoke$arity$variadic(G__22107,seq22106__$1);
});

om_tools.dom.h1.cljs$lang$maxFixedArity = (1);

om_tools.dom.h2 = (function om_tools$dom$h2(var_args){
var args22110 = [];
var len__5570__auto___22692 = arguments.length;
var i__5571__auto___22693 = (0);
while(true){
if((i__5571__auto___22693 < len__5570__auto___22692)){
args22110.push((arguments[i__5571__auto___22693]));

var G__22694 = (i__5571__auto___22693 + (1));
i__5571__auto___22693 = G__22694;
continue;
} else {
}
break;
}

var G__22114 = args22110.length;
switch (G__22114) {
case 0:
return om_tools.dom.h2.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22110.slice((1)),(0)));
return om_tools.dom.h2.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.h2.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.h2,null,null);
});

om_tools.dom.h2.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.h2,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.h2.cljs$lang$applyTo = (function (seq22111){
var G__22112 = cljs.core.first(seq22111);
var seq22111__$1 = cljs.core.next(seq22111);
return om_tools.dom.h2.cljs$core$IFn$_invoke$arity$variadic(G__22112,seq22111__$1);
});

om_tools.dom.h2.cljs$lang$maxFixedArity = (1);

om_tools.dom.h3 = (function om_tools$dom$h3(var_args){
var args22115 = [];
var len__5570__auto___22696 = arguments.length;
var i__5571__auto___22697 = (0);
while(true){
if((i__5571__auto___22697 < len__5570__auto___22696)){
args22115.push((arguments[i__5571__auto___22697]));

var G__22698 = (i__5571__auto___22697 + (1));
i__5571__auto___22697 = G__22698;
continue;
} else {
}
break;
}

var G__22119 = args22115.length;
switch (G__22119) {
case 0:
return om_tools.dom.h3.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22115.slice((1)),(0)));
return om_tools.dom.h3.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.h3.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.h3,null,null);
});

om_tools.dom.h3.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.h3,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.h3.cljs$lang$applyTo = (function (seq22116){
var G__22117 = cljs.core.first(seq22116);
var seq22116__$1 = cljs.core.next(seq22116);
return om_tools.dom.h3.cljs$core$IFn$_invoke$arity$variadic(G__22117,seq22116__$1);
});

om_tools.dom.h3.cljs$lang$maxFixedArity = (1);

om_tools.dom.h4 = (function om_tools$dom$h4(var_args){
var args22120 = [];
var len__5570__auto___22700 = arguments.length;
var i__5571__auto___22701 = (0);
while(true){
if((i__5571__auto___22701 < len__5570__auto___22700)){
args22120.push((arguments[i__5571__auto___22701]));

var G__22702 = (i__5571__auto___22701 + (1));
i__5571__auto___22701 = G__22702;
continue;
} else {
}
break;
}

var G__22124 = args22120.length;
switch (G__22124) {
case 0:
return om_tools.dom.h4.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22120.slice((1)),(0)));
return om_tools.dom.h4.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.h4.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.h4,null,null);
});

om_tools.dom.h4.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.h4,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.h4.cljs$lang$applyTo = (function (seq22121){
var G__22122 = cljs.core.first(seq22121);
var seq22121__$1 = cljs.core.next(seq22121);
return om_tools.dom.h4.cljs$core$IFn$_invoke$arity$variadic(G__22122,seq22121__$1);
});

om_tools.dom.h4.cljs$lang$maxFixedArity = (1);

om_tools.dom.h5 = (function om_tools$dom$h5(var_args){
var args22125 = [];
var len__5570__auto___22704 = arguments.length;
var i__5571__auto___22705 = (0);
while(true){
if((i__5571__auto___22705 < len__5570__auto___22704)){
args22125.push((arguments[i__5571__auto___22705]));

var G__22706 = (i__5571__auto___22705 + (1));
i__5571__auto___22705 = G__22706;
continue;
} else {
}
break;
}

var G__22129 = args22125.length;
switch (G__22129) {
case 0:
return om_tools.dom.h5.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22125.slice((1)),(0)));
return om_tools.dom.h5.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.h5.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.h5,null,null);
});

om_tools.dom.h5.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.h5,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.h5.cljs$lang$applyTo = (function (seq22126){
var G__22127 = cljs.core.first(seq22126);
var seq22126__$1 = cljs.core.next(seq22126);
return om_tools.dom.h5.cljs$core$IFn$_invoke$arity$variadic(G__22127,seq22126__$1);
});

om_tools.dom.h5.cljs$lang$maxFixedArity = (1);

om_tools.dom.h6 = (function om_tools$dom$h6(var_args){
var args22130 = [];
var len__5570__auto___22708 = arguments.length;
var i__5571__auto___22709 = (0);
while(true){
if((i__5571__auto___22709 < len__5570__auto___22708)){
args22130.push((arguments[i__5571__auto___22709]));

var G__22710 = (i__5571__auto___22709 + (1));
i__5571__auto___22709 = G__22710;
continue;
} else {
}
break;
}

var G__22134 = args22130.length;
switch (G__22134) {
case 0:
return om_tools.dom.h6.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22130.slice((1)),(0)));
return om_tools.dom.h6.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.h6.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.h6,null,null);
});

om_tools.dom.h6.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.h6,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.h6.cljs$lang$applyTo = (function (seq22131){
var G__22132 = cljs.core.first(seq22131);
var seq22131__$1 = cljs.core.next(seq22131);
return om_tools.dom.h6.cljs$core$IFn$_invoke$arity$variadic(G__22132,seq22131__$1);
});

om_tools.dom.h6.cljs$lang$maxFixedArity = (1);

om_tools.dom.head = (function om_tools$dom$head(var_args){
var args22135 = [];
var len__5570__auto___22712 = arguments.length;
var i__5571__auto___22713 = (0);
while(true){
if((i__5571__auto___22713 < len__5570__auto___22712)){
args22135.push((arguments[i__5571__auto___22713]));

var G__22714 = (i__5571__auto___22713 + (1));
i__5571__auto___22713 = G__22714;
continue;
} else {
}
break;
}

var G__22139 = args22135.length;
switch (G__22139) {
case 0:
return om_tools.dom.head.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22135.slice((1)),(0)));
return om_tools.dom.head.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.head.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.head,null,null);
});

om_tools.dom.head.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.head,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.head.cljs$lang$applyTo = (function (seq22136){
var G__22137 = cljs.core.first(seq22136);
var seq22136__$1 = cljs.core.next(seq22136);
return om_tools.dom.head.cljs$core$IFn$_invoke$arity$variadic(G__22137,seq22136__$1);
});

om_tools.dom.head.cljs$lang$maxFixedArity = (1);

om_tools.dom.header = (function om_tools$dom$header(var_args){
var args22140 = [];
var len__5570__auto___22716 = arguments.length;
var i__5571__auto___22717 = (0);
while(true){
if((i__5571__auto___22717 < len__5570__auto___22716)){
args22140.push((arguments[i__5571__auto___22717]));

var G__22718 = (i__5571__auto___22717 + (1));
i__5571__auto___22717 = G__22718;
continue;
} else {
}
break;
}

var G__22144 = args22140.length;
switch (G__22144) {
case 0:
return om_tools.dom.header.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22140.slice((1)),(0)));
return om_tools.dom.header.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.header.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.header,null,null);
});

om_tools.dom.header.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.header,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.header.cljs$lang$applyTo = (function (seq22141){
var G__22142 = cljs.core.first(seq22141);
var seq22141__$1 = cljs.core.next(seq22141);
return om_tools.dom.header.cljs$core$IFn$_invoke$arity$variadic(G__22142,seq22141__$1);
});

om_tools.dom.header.cljs$lang$maxFixedArity = (1);

om_tools.dom.hr = (function om_tools$dom$hr(var_args){
var args22145 = [];
var len__5570__auto___22720 = arguments.length;
var i__5571__auto___22721 = (0);
while(true){
if((i__5571__auto___22721 < len__5570__auto___22720)){
args22145.push((arguments[i__5571__auto___22721]));

var G__22722 = (i__5571__auto___22721 + (1));
i__5571__auto___22721 = G__22722;
continue;
} else {
}
break;
}

var G__22149 = args22145.length;
switch (G__22149) {
case 0:
return om_tools.dom.hr.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22145.slice((1)),(0)));
return om_tools.dom.hr.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.hr.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.hr,null,null);
});

om_tools.dom.hr.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.hr,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.hr.cljs$lang$applyTo = (function (seq22146){
var G__22147 = cljs.core.first(seq22146);
var seq22146__$1 = cljs.core.next(seq22146);
return om_tools.dom.hr.cljs$core$IFn$_invoke$arity$variadic(G__22147,seq22146__$1);
});

om_tools.dom.hr.cljs$lang$maxFixedArity = (1);

om_tools.dom.html = (function om_tools$dom$html(var_args){
var args22150 = [];
var len__5570__auto___22724 = arguments.length;
var i__5571__auto___22725 = (0);
while(true){
if((i__5571__auto___22725 < len__5570__auto___22724)){
args22150.push((arguments[i__5571__auto___22725]));

var G__22726 = (i__5571__auto___22725 + (1));
i__5571__auto___22725 = G__22726;
continue;
} else {
}
break;
}

var G__22154 = args22150.length;
switch (G__22154) {
case 0:
return om_tools.dom.html.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22150.slice((1)),(0)));
return om_tools.dom.html.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.html.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.html,null,null);
});

om_tools.dom.html.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.html,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.html.cljs$lang$applyTo = (function (seq22151){
var G__22152 = cljs.core.first(seq22151);
var seq22151__$1 = cljs.core.next(seq22151);
return om_tools.dom.html.cljs$core$IFn$_invoke$arity$variadic(G__22152,seq22151__$1);
});

om_tools.dom.html.cljs$lang$maxFixedArity = (1);

om_tools.dom.i = (function om_tools$dom$i(var_args){
var args22155 = [];
var len__5570__auto___22728 = arguments.length;
var i__5571__auto___22729 = (0);
while(true){
if((i__5571__auto___22729 < len__5570__auto___22728)){
args22155.push((arguments[i__5571__auto___22729]));

var G__22730 = (i__5571__auto___22729 + (1));
i__5571__auto___22729 = G__22730;
continue;
} else {
}
break;
}

var G__22159 = args22155.length;
switch (G__22159) {
case 0:
return om_tools.dom.i.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22155.slice((1)),(0)));
return om_tools.dom.i.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.i.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.i,null,null);
});

om_tools.dom.i.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.i,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.i.cljs$lang$applyTo = (function (seq22156){
var G__22157 = cljs.core.first(seq22156);
var seq22156__$1 = cljs.core.next(seq22156);
return om_tools.dom.i.cljs$core$IFn$_invoke$arity$variadic(G__22157,seq22156__$1);
});

om_tools.dom.i.cljs$lang$maxFixedArity = (1);

om_tools.dom.iframe = (function om_tools$dom$iframe(var_args){
var args22160 = [];
var len__5570__auto___22732 = arguments.length;
var i__5571__auto___22733 = (0);
while(true){
if((i__5571__auto___22733 < len__5570__auto___22732)){
args22160.push((arguments[i__5571__auto___22733]));

var G__22734 = (i__5571__auto___22733 + (1));
i__5571__auto___22733 = G__22734;
continue;
} else {
}
break;
}

var G__22164 = args22160.length;
switch (G__22164) {
case 0:
return om_tools.dom.iframe.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22160.slice((1)),(0)));
return om_tools.dom.iframe.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.iframe.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.iframe,null,null);
});

om_tools.dom.iframe.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.iframe,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.iframe.cljs$lang$applyTo = (function (seq22161){
var G__22162 = cljs.core.first(seq22161);
var seq22161__$1 = cljs.core.next(seq22161);
return om_tools.dom.iframe.cljs$core$IFn$_invoke$arity$variadic(G__22162,seq22161__$1);
});

om_tools.dom.iframe.cljs$lang$maxFixedArity = (1);

om_tools.dom.img = (function om_tools$dom$img(var_args){
var args22165 = [];
var len__5570__auto___22736 = arguments.length;
var i__5571__auto___22737 = (0);
while(true){
if((i__5571__auto___22737 < len__5570__auto___22736)){
args22165.push((arguments[i__5571__auto___22737]));

var G__22738 = (i__5571__auto___22737 + (1));
i__5571__auto___22737 = G__22738;
continue;
} else {
}
break;
}

var G__22169 = args22165.length;
switch (G__22169) {
case 0:
return om_tools.dom.img.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22165.slice((1)),(0)));
return om_tools.dom.img.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.img.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.img,null,null);
});

om_tools.dom.img.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.img,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.img.cljs$lang$applyTo = (function (seq22166){
var G__22167 = cljs.core.first(seq22166);
var seq22166__$1 = cljs.core.next(seq22166);
return om_tools.dom.img.cljs$core$IFn$_invoke$arity$variadic(G__22167,seq22166__$1);
});

om_tools.dom.img.cljs$lang$maxFixedArity = (1);

om_tools.dom.ins = (function om_tools$dom$ins(var_args){
var args22170 = [];
var len__5570__auto___22740 = arguments.length;
var i__5571__auto___22741 = (0);
while(true){
if((i__5571__auto___22741 < len__5570__auto___22740)){
args22170.push((arguments[i__5571__auto___22741]));

var G__22742 = (i__5571__auto___22741 + (1));
i__5571__auto___22741 = G__22742;
continue;
} else {
}
break;
}

var G__22174 = args22170.length;
switch (G__22174) {
case 0:
return om_tools.dom.ins.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22170.slice((1)),(0)));
return om_tools.dom.ins.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.ins.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.ins,null,null);
});

om_tools.dom.ins.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.ins,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.ins.cljs$lang$applyTo = (function (seq22171){
var G__22172 = cljs.core.first(seq22171);
var seq22171__$1 = cljs.core.next(seq22171);
return om_tools.dom.ins.cljs$core$IFn$_invoke$arity$variadic(G__22172,seq22171__$1);
});

om_tools.dom.ins.cljs$lang$maxFixedArity = (1);

om_tools.dom.kbd = (function om_tools$dom$kbd(var_args){
var args22175 = [];
var len__5570__auto___22744 = arguments.length;
var i__5571__auto___22745 = (0);
while(true){
if((i__5571__auto___22745 < len__5570__auto___22744)){
args22175.push((arguments[i__5571__auto___22745]));

var G__22746 = (i__5571__auto___22745 + (1));
i__5571__auto___22745 = G__22746;
continue;
} else {
}
break;
}

var G__22179 = args22175.length;
switch (G__22179) {
case 0:
return om_tools.dom.kbd.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22175.slice((1)),(0)));
return om_tools.dom.kbd.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.kbd.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.kbd,null,null);
});

om_tools.dom.kbd.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.kbd,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.kbd.cljs$lang$applyTo = (function (seq22176){
var G__22177 = cljs.core.first(seq22176);
var seq22176__$1 = cljs.core.next(seq22176);
return om_tools.dom.kbd.cljs$core$IFn$_invoke$arity$variadic(G__22177,seq22176__$1);
});

om_tools.dom.kbd.cljs$lang$maxFixedArity = (1);

om_tools.dom.keygen = (function om_tools$dom$keygen(var_args){
var args22180 = [];
var len__5570__auto___22748 = arguments.length;
var i__5571__auto___22749 = (0);
while(true){
if((i__5571__auto___22749 < len__5570__auto___22748)){
args22180.push((arguments[i__5571__auto___22749]));

var G__22750 = (i__5571__auto___22749 + (1));
i__5571__auto___22749 = G__22750;
continue;
} else {
}
break;
}

var G__22184 = args22180.length;
switch (G__22184) {
case 0:
return om_tools.dom.keygen.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22180.slice((1)),(0)));
return om_tools.dom.keygen.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.keygen.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.keygen,null,null);
});

om_tools.dom.keygen.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.keygen,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.keygen.cljs$lang$applyTo = (function (seq22181){
var G__22182 = cljs.core.first(seq22181);
var seq22181__$1 = cljs.core.next(seq22181);
return om_tools.dom.keygen.cljs$core$IFn$_invoke$arity$variadic(G__22182,seq22181__$1);
});

om_tools.dom.keygen.cljs$lang$maxFixedArity = (1);

om_tools.dom.label = (function om_tools$dom$label(var_args){
var args22185 = [];
var len__5570__auto___22752 = arguments.length;
var i__5571__auto___22753 = (0);
while(true){
if((i__5571__auto___22753 < len__5570__auto___22752)){
args22185.push((arguments[i__5571__auto___22753]));

var G__22754 = (i__5571__auto___22753 + (1));
i__5571__auto___22753 = G__22754;
continue;
} else {
}
break;
}

var G__22189 = args22185.length;
switch (G__22189) {
case 0:
return om_tools.dom.label.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22185.slice((1)),(0)));
return om_tools.dom.label.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.label.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.label,null,null);
});

om_tools.dom.label.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.label,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.label.cljs$lang$applyTo = (function (seq22186){
var G__22187 = cljs.core.first(seq22186);
var seq22186__$1 = cljs.core.next(seq22186);
return om_tools.dom.label.cljs$core$IFn$_invoke$arity$variadic(G__22187,seq22186__$1);
});

om_tools.dom.label.cljs$lang$maxFixedArity = (1);

om_tools.dom.legend = (function om_tools$dom$legend(var_args){
var args22190 = [];
var len__5570__auto___22756 = arguments.length;
var i__5571__auto___22757 = (0);
while(true){
if((i__5571__auto___22757 < len__5570__auto___22756)){
args22190.push((arguments[i__5571__auto___22757]));

var G__22758 = (i__5571__auto___22757 + (1));
i__5571__auto___22757 = G__22758;
continue;
} else {
}
break;
}

var G__22194 = args22190.length;
switch (G__22194) {
case 0:
return om_tools.dom.legend.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22190.slice((1)),(0)));
return om_tools.dom.legend.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.legend.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.legend,null,null);
});

om_tools.dom.legend.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.legend,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.legend.cljs$lang$applyTo = (function (seq22191){
var G__22192 = cljs.core.first(seq22191);
var seq22191__$1 = cljs.core.next(seq22191);
return om_tools.dom.legend.cljs$core$IFn$_invoke$arity$variadic(G__22192,seq22191__$1);
});

om_tools.dom.legend.cljs$lang$maxFixedArity = (1);

om_tools.dom.li = (function om_tools$dom$li(var_args){
var args22195 = [];
var len__5570__auto___22760 = arguments.length;
var i__5571__auto___22761 = (0);
while(true){
if((i__5571__auto___22761 < len__5570__auto___22760)){
args22195.push((arguments[i__5571__auto___22761]));

var G__22762 = (i__5571__auto___22761 + (1));
i__5571__auto___22761 = G__22762;
continue;
} else {
}
break;
}

var G__22199 = args22195.length;
switch (G__22199) {
case 0:
return om_tools.dom.li.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22195.slice((1)),(0)));
return om_tools.dom.li.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.li.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.li,null,null);
});

om_tools.dom.li.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.li,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.li.cljs$lang$applyTo = (function (seq22196){
var G__22197 = cljs.core.first(seq22196);
var seq22196__$1 = cljs.core.next(seq22196);
return om_tools.dom.li.cljs$core$IFn$_invoke$arity$variadic(G__22197,seq22196__$1);
});

om_tools.dom.li.cljs$lang$maxFixedArity = (1);

om_tools.dom.link = (function om_tools$dom$link(var_args){
var args22200 = [];
var len__5570__auto___22764 = arguments.length;
var i__5571__auto___22765 = (0);
while(true){
if((i__5571__auto___22765 < len__5570__auto___22764)){
args22200.push((arguments[i__5571__auto___22765]));

var G__22766 = (i__5571__auto___22765 + (1));
i__5571__auto___22765 = G__22766;
continue;
} else {
}
break;
}

var G__22204 = args22200.length;
switch (G__22204) {
case 0:
return om_tools.dom.link.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22200.slice((1)),(0)));
return om_tools.dom.link.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.link.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.link,null,null);
});

om_tools.dom.link.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.link,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.link.cljs$lang$applyTo = (function (seq22201){
var G__22202 = cljs.core.first(seq22201);
var seq22201__$1 = cljs.core.next(seq22201);
return om_tools.dom.link.cljs$core$IFn$_invoke$arity$variadic(G__22202,seq22201__$1);
});

om_tools.dom.link.cljs$lang$maxFixedArity = (1);

om_tools.dom.main = (function om_tools$dom$main(var_args){
var args22205 = [];
var len__5570__auto___22768 = arguments.length;
var i__5571__auto___22769 = (0);
while(true){
if((i__5571__auto___22769 < len__5570__auto___22768)){
args22205.push((arguments[i__5571__auto___22769]));

var G__22770 = (i__5571__auto___22769 + (1));
i__5571__auto___22769 = G__22770;
continue;
} else {
}
break;
}

var G__22209 = args22205.length;
switch (G__22209) {
case 0:
return om_tools.dom.main.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22205.slice((1)),(0)));
return om_tools.dom.main.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.main.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.main,null,null);
});

om_tools.dom.main.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.main,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.main.cljs$lang$applyTo = (function (seq22206){
var G__22207 = cljs.core.first(seq22206);
var seq22206__$1 = cljs.core.next(seq22206);
return om_tools.dom.main.cljs$core$IFn$_invoke$arity$variadic(G__22207,seq22206__$1);
});

om_tools.dom.main.cljs$lang$maxFixedArity = (1);

om_tools.dom.map = (function om_tools$dom$map(var_args){
var args22210 = [];
var len__5570__auto___22772 = arguments.length;
var i__5571__auto___22773 = (0);
while(true){
if((i__5571__auto___22773 < len__5570__auto___22772)){
args22210.push((arguments[i__5571__auto___22773]));

var G__22774 = (i__5571__auto___22773 + (1));
i__5571__auto___22773 = G__22774;
continue;
} else {
}
break;
}

var G__22214 = args22210.length;
switch (G__22214) {
case 0:
return om_tools.dom.map.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22210.slice((1)),(0)));
return om_tools.dom.map.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.map.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.map,null,null);
});

om_tools.dom.map.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.map,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.map.cljs$lang$applyTo = (function (seq22211){
var G__22212 = cljs.core.first(seq22211);
var seq22211__$1 = cljs.core.next(seq22211);
return om_tools.dom.map.cljs$core$IFn$_invoke$arity$variadic(G__22212,seq22211__$1);
});

om_tools.dom.map.cljs$lang$maxFixedArity = (1);

om_tools.dom.mark = (function om_tools$dom$mark(var_args){
var args22215 = [];
var len__5570__auto___22776 = arguments.length;
var i__5571__auto___22777 = (0);
while(true){
if((i__5571__auto___22777 < len__5570__auto___22776)){
args22215.push((arguments[i__5571__auto___22777]));

var G__22778 = (i__5571__auto___22777 + (1));
i__5571__auto___22777 = G__22778;
continue;
} else {
}
break;
}

var G__22219 = args22215.length;
switch (G__22219) {
case 0:
return om_tools.dom.mark.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22215.slice((1)),(0)));
return om_tools.dom.mark.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.mark.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.mark,null,null);
});

om_tools.dom.mark.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.mark,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.mark.cljs$lang$applyTo = (function (seq22216){
var G__22217 = cljs.core.first(seq22216);
var seq22216__$1 = cljs.core.next(seq22216);
return om_tools.dom.mark.cljs$core$IFn$_invoke$arity$variadic(G__22217,seq22216__$1);
});

om_tools.dom.mark.cljs$lang$maxFixedArity = (1);

om_tools.dom.marquee = (function om_tools$dom$marquee(var_args){
var args22220 = [];
var len__5570__auto___22780 = arguments.length;
var i__5571__auto___22781 = (0);
while(true){
if((i__5571__auto___22781 < len__5570__auto___22780)){
args22220.push((arguments[i__5571__auto___22781]));

var G__22782 = (i__5571__auto___22781 + (1));
i__5571__auto___22781 = G__22782;
continue;
} else {
}
break;
}

var G__22224 = args22220.length;
switch (G__22224) {
case 0:
return om_tools.dom.marquee.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22220.slice((1)),(0)));
return om_tools.dom.marquee.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.marquee.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.marquee,null,null);
});

om_tools.dom.marquee.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.marquee,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.marquee.cljs$lang$applyTo = (function (seq22221){
var G__22222 = cljs.core.first(seq22221);
var seq22221__$1 = cljs.core.next(seq22221);
return om_tools.dom.marquee.cljs$core$IFn$_invoke$arity$variadic(G__22222,seq22221__$1);
});

om_tools.dom.marquee.cljs$lang$maxFixedArity = (1);

om_tools.dom.menu = (function om_tools$dom$menu(var_args){
var args22225 = [];
var len__5570__auto___22784 = arguments.length;
var i__5571__auto___22785 = (0);
while(true){
if((i__5571__auto___22785 < len__5570__auto___22784)){
args22225.push((arguments[i__5571__auto___22785]));

var G__22786 = (i__5571__auto___22785 + (1));
i__5571__auto___22785 = G__22786;
continue;
} else {
}
break;
}

var G__22229 = args22225.length;
switch (G__22229) {
case 0:
return om_tools.dom.menu.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22225.slice((1)),(0)));
return om_tools.dom.menu.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.menu.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.menu,null,null);
});

om_tools.dom.menu.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.menu,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.menu.cljs$lang$applyTo = (function (seq22226){
var G__22227 = cljs.core.first(seq22226);
var seq22226__$1 = cljs.core.next(seq22226);
return om_tools.dom.menu.cljs$core$IFn$_invoke$arity$variadic(G__22227,seq22226__$1);
});

om_tools.dom.menu.cljs$lang$maxFixedArity = (1);

om_tools.dom.menuitem = (function om_tools$dom$menuitem(var_args){
var args22230 = [];
var len__5570__auto___22788 = arguments.length;
var i__5571__auto___22789 = (0);
while(true){
if((i__5571__auto___22789 < len__5570__auto___22788)){
args22230.push((arguments[i__5571__auto___22789]));

var G__22790 = (i__5571__auto___22789 + (1));
i__5571__auto___22789 = G__22790;
continue;
} else {
}
break;
}

var G__22234 = args22230.length;
switch (G__22234) {
case 0:
return om_tools.dom.menuitem.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22230.slice((1)),(0)));
return om_tools.dom.menuitem.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.menuitem.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.menuitem,null,null);
});

om_tools.dom.menuitem.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.menuitem,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.menuitem.cljs$lang$applyTo = (function (seq22231){
var G__22232 = cljs.core.first(seq22231);
var seq22231__$1 = cljs.core.next(seq22231);
return om_tools.dom.menuitem.cljs$core$IFn$_invoke$arity$variadic(G__22232,seq22231__$1);
});

om_tools.dom.menuitem.cljs$lang$maxFixedArity = (1);

om_tools.dom.meta = (function om_tools$dom$meta(var_args){
var args22235 = [];
var len__5570__auto___22792 = arguments.length;
var i__5571__auto___22793 = (0);
while(true){
if((i__5571__auto___22793 < len__5570__auto___22792)){
args22235.push((arguments[i__5571__auto___22793]));

var G__22794 = (i__5571__auto___22793 + (1));
i__5571__auto___22793 = G__22794;
continue;
} else {
}
break;
}

var G__22239 = args22235.length;
switch (G__22239) {
case 0:
return om_tools.dom.meta.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22235.slice((1)),(0)));
return om_tools.dom.meta.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.meta.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.meta,null,null);
});

om_tools.dom.meta.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.meta,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.meta.cljs$lang$applyTo = (function (seq22236){
var G__22237 = cljs.core.first(seq22236);
var seq22236__$1 = cljs.core.next(seq22236);
return om_tools.dom.meta.cljs$core$IFn$_invoke$arity$variadic(G__22237,seq22236__$1);
});

om_tools.dom.meta.cljs$lang$maxFixedArity = (1);

om_tools.dom.meter = (function om_tools$dom$meter(var_args){
var args22240 = [];
var len__5570__auto___22796 = arguments.length;
var i__5571__auto___22797 = (0);
while(true){
if((i__5571__auto___22797 < len__5570__auto___22796)){
args22240.push((arguments[i__5571__auto___22797]));

var G__22798 = (i__5571__auto___22797 + (1));
i__5571__auto___22797 = G__22798;
continue;
} else {
}
break;
}

var G__22244 = args22240.length;
switch (G__22244) {
case 0:
return om_tools.dom.meter.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22240.slice((1)),(0)));
return om_tools.dom.meter.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.meter.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.meter,null,null);
});

om_tools.dom.meter.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.meter,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.meter.cljs$lang$applyTo = (function (seq22241){
var G__22242 = cljs.core.first(seq22241);
var seq22241__$1 = cljs.core.next(seq22241);
return om_tools.dom.meter.cljs$core$IFn$_invoke$arity$variadic(G__22242,seq22241__$1);
});

om_tools.dom.meter.cljs$lang$maxFixedArity = (1);

om_tools.dom.nav = (function om_tools$dom$nav(var_args){
var args22245 = [];
var len__5570__auto___22800 = arguments.length;
var i__5571__auto___22801 = (0);
while(true){
if((i__5571__auto___22801 < len__5570__auto___22800)){
args22245.push((arguments[i__5571__auto___22801]));

var G__22802 = (i__5571__auto___22801 + (1));
i__5571__auto___22801 = G__22802;
continue;
} else {
}
break;
}

var G__22249 = args22245.length;
switch (G__22249) {
case 0:
return om_tools.dom.nav.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22245.slice((1)),(0)));
return om_tools.dom.nav.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.nav.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.nav,null,null);
});

om_tools.dom.nav.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.nav,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.nav.cljs$lang$applyTo = (function (seq22246){
var G__22247 = cljs.core.first(seq22246);
var seq22246__$1 = cljs.core.next(seq22246);
return om_tools.dom.nav.cljs$core$IFn$_invoke$arity$variadic(G__22247,seq22246__$1);
});

om_tools.dom.nav.cljs$lang$maxFixedArity = (1);

om_tools.dom.noscript = (function om_tools$dom$noscript(var_args){
var args22250 = [];
var len__5570__auto___22804 = arguments.length;
var i__5571__auto___22805 = (0);
while(true){
if((i__5571__auto___22805 < len__5570__auto___22804)){
args22250.push((arguments[i__5571__auto___22805]));

var G__22806 = (i__5571__auto___22805 + (1));
i__5571__auto___22805 = G__22806;
continue;
} else {
}
break;
}

var G__22254 = args22250.length;
switch (G__22254) {
case 0:
return om_tools.dom.noscript.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22250.slice((1)),(0)));
return om_tools.dom.noscript.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.noscript.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.noscript,null,null);
});

om_tools.dom.noscript.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.noscript,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.noscript.cljs$lang$applyTo = (function (seq22251){
var G__22252 = cljs.core.first(seq22251);
var seq22251__$1 = cljs.core.next(seq22251);
return om_tools.dom.noscript.cljs$core$IFn$_invoke$arity$variadic(G__22252,seq22251__$1);
});

om_tools.dom.noscript.cljs$lang$maxFixedArity = (1);

om_tools.dom.object = (function om_tools$dom$object(var_args){
var args22255 = [];
var len__5570__auto___22808 = arguments.length;
var i__5571__auto___22809 = (0);
while(true){
if((i__5571__auto___22809 < len__5570__auto___22808)){
args22255.push((arguments[i__5571__auto___22809]));

var G__22810 = (i__5571__auto___22809 + (1));
i__5571__auto___22809 = G__22810;
continue;
} else {
}
break;
}

var G__22259 = args22255.length;
switch (G__22259) {
case 0:
return om_tools.dom.object.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22255.slice((1)),(0)));
return om_tools.dom.object.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.object.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.object,null,null);
});

om_tools.dom.object.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.object,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.object.cljs$lang$applyTo = (function (seq22256){
var G__22257 = cljs.core.first(seq22256);
var seq22256__$1 = cljs.core.next(seq22256);
return om_tools.dom.object.cljs$core$IFn$_invoke$arity$variadic(G__22257,seq22256__$1);
});

om_tools.dom.object.cljs$lang$maxFixedArity = (1);

om_tools.dom.ol = (function om_tools$dom$ol(var_args){
var args22260 = [];
var len__5570__auto___22812 = arguments.length;
var i__5571__auto___22813 = (0);
while(true){
if((i__5571__auto___22813 < len__5570__auto___22812)){
args22260.push((arguments[i__5571__auto___22813]));

var G__22814 = (i__5571__auto___22813 + (1));
i__5571__auto___22813 = G__22814;
continue;
} else {
}
break;
}

var G__22264 = args22260.length;
switch (G__22264) {
case 0:
return om_tools.dom.ol.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22260.slice((1)),(0)));
return om_tools.dom.ol.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.ol.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.ol,null,null);
});

om_tools.dom.ol.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.ol,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.ol.cljs$lang$applyTo = (function (seq22261){
var G__22262 = cljs.core.first(seq22261);
var seq22261__$1 = cljs.core.next(seq22261);
return om_tools.dom.ol.cljs$core$IFn$_invoke$arity$variadic(G__22262,seq22261__$1);
});

om_tools.dom.ol.cljs$lang$maxFixedArity = (1);

om_tools.dom.optgroup = (function om_tools$dom$optgroup(var_args){
var args22265 = [];
var len__5570__auto___22816 = arguments.length;
var i__5571__auto___22817 = (0);
while(true){
if((i__5571__auto___22817 < len__5570__auto___22816)){
args22265.push((arguments[i__5571__auto___22817]));

var G__22818 = (i__5571__auto___22817 + (1));
i__5571__auto___22817 = G__22818;
continue;
} else {
}
break;
}

var G__22269 = args22265.length;
switch (G__22269) {
case 0:
return om_tools.dom.optgroup.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22265.slice((1)),(0)));
return om_tools.dom.optgroup.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.optgroup.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.optgroup,null,null);
});

om_tools.dom.optgroup.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.optgroup,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.optgroup.cljs$lang$applyTo = (function (seq22266){
var G__22267 = cljs.core.first(seq22266);
var seq22266__$1 = cljs.core.next(seq22266);
return om_tools.dom.optgroup.cljs$core$IFn$_invoke$arity$variadic(G__22267,seq22266__$1);
});

om_tools.dom.optgroup.cljs$lang$maxFixedArity = (1);

om_tools.dom.output = (function om_tools$dom$output(var_args){
var args22270 = [];
var len__5570__auto___22820 = arguments.length;
var i__5571__auto___22821 = (0);
while(true){
if((i__5571__auto___22821 < len__5570__auto___22820)){
args22270.push((arguments[i__5571__auto___22821]));

var G__22822 = (i__5571__auto___22821 + (1));
i__5571__auto___22821 = G__22822;
continue;
} else {
}
break;
}

var G__22274 = args22270.length;
switch (G__22274) {
case 0:
return om_tools.dom.output.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22270.slice((1)),(0)));
return om_tools.dom.output.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.output.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.output,null,null);
});

om_tools.dom.output.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.output,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.output.cljs$lang$applyTo = (function (seq22271){
var G__22272 = cljs.core.first(seq22271);
var seq22271__$1 = cljs.core.next(seq22271);
return om_tools.dom.output.cljs$core$IFn$_invoke$arity$variadic(G__22272,seq22271__$1);
});

om_tools.dom.output.cljs$lang$maxFixedArity = (1);

om_tools.dom.p = (function om_tools$dom$p(var_args){
var args22275 = [];
var len__5570__auto___22824 = arguments.length;
var i__5571__auto___22825 = (0);
while(true){
if((i__5571__auto___22825 < len__5570__auto___22824)){
args22275.push((arguments[i__5571__auto___22825]));

var G__22826 = (i__5571__auto___22825 + (1));
i__5571__auto___22825 = G__22826;
continue;
} else {
}
break;
}

var G__22279 = args22275.length;
switch (G__22279) {
case 0:
return om_tools.dom.p.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22275.slice((1)),(0)));
return om_tools.dom.p.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.p.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.p,null,null);
});

om_tools.dom.p.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.p,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.p.cljs$lang$applyTo = (function (seq22276){
var G__22277 = cljs.core.first(seq22276);
var seq22276__$1 = cljs.core.next(seq22276);
return om_tools.dom.p.cljs$core$IFn$_invoke$arity$variadic(G__22277,seq22276__$1);
});

om_tools.dom.p.cljs$lang$maxFixedArity = (1);

om_tools.dom.param = (function om_tools$dom$param(var_args){
var args22280 = [];
var len__5570__auto___22828 = arguments.length;
var i__5571__auto___22829 = (0);
while(true){
if((i__5571__auto___22829 < len__5570__auto___22828)){
args22280.push((arguments[i__5571__auto___22829]));

var G__22830 = (i__5571__auto___22829 + (1));
i__5571__auto___22829 = G__22830;
continue;
} else {
}
break;
}

var G__22284 = args22280.length;
switch (G__22284) {
case 0:
return om_tools.dom.param.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22280.slice((1)),(0)));
return om_tools.dom.param.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.param.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.param,null,null);
});

om_tools.dom.param.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.param,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.param.cljs$lang$applyTo = (function (seq22281){
var G__22282 = cljs.core.first(seq22281);
var seq22281__$1 = cljs.core.next(seq22281);
return om_tools.dom.param.cljs$core$IFn$_invoke$arity$variadic(G__22282,seq22281__$1);
});

om_tools.dom.param.cljs$lang$maxFixedArity = (1);

om_tools.dom.pre = (function om_tools$dom$pre(var_args){
var args22285 = [];
var len__5570__auto___22832 = arguments.length;
var i__5571__auto___22833 = (0);
while(true){
if((i__5571__auto___22833 < len__5570__auto___22832)){
args22285.push((arguments[i__5571__auto___22833]));

var G__22834 = (i__5571__auto___22833 + (1));
i__5571__auto___22833 = G__22834;
continue;
} else {
}
break;
}

var G__22289 = args22285.length;
switch (G__22289) {
case 0:
return om_tools.dom.pre.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22285.slice((1)),(0)));
return om_tools.dom.pre.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.pre.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.pre,null,null);
});

om_tools.dom.pre.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.pre,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.pre.cljs$lang$applyTo = (function (seq22286){
var G__22287 = cljs.core.first(seq22286);
var seq22286__$1 = cljs.core.next(seq22286);
return om_tools.dom.pre.cljs$core$IFn$_invoke$arity$variadic(G__22287,seq22286__$1);
});

om_tools.dom.pre.cljs$lang$maxFixedArity = (1);

om_tools.dom.progress = (function om_tools$dom$progress(var_args){
var args22290 = [];
var len__5570__auto___22836 = arguments.length;
var i__5571__auto___22837 = (0);
while(true){
if((i__5571__auto___22837 < len__5570__auto___22836)){
args22290.push((arguments[i__5571__auto___22837]));

var G__22838 = (i__5571__auto___22837 + (1));
i__5571__auto___22837 = G__22838;
continue;
} else {
}
break;
}

var G__22294 = args22290.length;
switch (G__22294) {
case 0:
return om_tools.dom.progress.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22290.slice((1)),(0)));
return om_tools.dom.progress.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.progress.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.progress,null,null);
});

om_tools.dom.progress.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.progress,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.progress.cljs$lang$applyTo = (function (seq22291){
var G__22292 = cljs.core.first(seq22291);
var seq22291__$1 = cljs.core.next(seq22291);
return om_tools.dom.progress.cljs$core$IFn$_invoke$arity$variadic(G__22292,seq22291__$1);
});

om_tools.dom.progress.cljs$lang$maxFixedArity = (1);

om_tools.dom.q = (function om_tools$dom$q(var_args){
var args22295 = [];
var len__5570__auto___22840 = arguments.length;
var i__5571__auto___22841 = (0);
while(true){
if((i__5571__auto___22841 < len__5570__auto___22840)){
args22295.push((arguments[i__5571__auto___22841]));

var G__22842 = (i__5571__auto___22841 + (1));
i__5571__auto___22841 = G__22842;
continue;
} else {
}
break;
}

var G__22299 = args22295.length;
switch (G__22299) {
case 0:
return om_tools.dom.q.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22295.slice((1)),(0)));
return om_tools.dom.q.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.q.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.q,null,null);
});

om_tools.dom.q.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.q,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.q.cljs$lang$applyTo = (function (seq22296){
var G__22297 = cljs.core.first(seq22296);
var seq22296__$1 = cljs.core.next(seq22296);
return om_tools.dom.q.cljs$core$IFn$_invoke$arity$variadic(G__22297,seq22296__$1);
});

om_tools.dom.q.cljs$lang$maxFixedArity = (1);

om_tools.dom.rp = (function om_tools$dom$rp(var_args){
var args22300 = [];
var len__5570__auto___22844 = arguments.length;
var i__5571__auto___22845 = (0);
while(true){
if((i__5571__auto___22845 < len__5570__auto___22844)){
args22300.push((arguments[i__5571__auto___22845]));

var G__22846 = (i__5571__auto___22845 + (1));
i__5571__auto___22845 = G__22846;
continue;
} else {
}
break;
}

var G__22304 = args22300.length;
switch (G__22304) {
case 0:
return om_tools.dom.rp.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22300.slice((1)),(0)));
return om_tools.dom.rp.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.rp.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.rp,null,null);
});

om_tools.dom.rp.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.rp,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.rp.cljs$lang$applyTo = (function (seq22301){
var G__22302 = cljs.core.first(seq22301);
var seq22301__$1 = cljs.core.next(seq22301);
return om_tools.dom.rp.cljs$core$IFn$_invoke$arity$variadic(G__22302,seq22301__$1);
});

om_tools.dom.rp.cljs$lang$maxFixedArity = (1);

om_tools.dom.rt = (function om_tools$dom$rt(var_args){
var args22305 = [];
var len__5570__auto___22848 = arguments.length;
var i__5571__auto___22849 = (0);
while(true){
if((i__5571__auto___22849 < len__5570__auto___22848)){
args22305.push((arguments[i__5571__auto___22849]));

var G__22850 = (i__5571__auto___22849 + (1));
i__5571__auto___22849 = G__22850;
continue;
} else {
}
break;
}

var G__22309 = args22305.length;
switch (G__22309) {
case 0:
return om_tools.dom.rt.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22305.slice((1)),(0)));
return om_tools.dom.rt.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.rt.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.rt,null,null);
});

om_tools.dom.rt.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.rt,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.rt.cljs$lang$applyTo = (function (seq22306){
var G__22307 = cljs.core.first(seq22306);
var seq22306__$1 = cljs.core.next(seq22306);
return om_tools.dom.rt.cljs$core$IFn$_invoke$arity$variadic(G__22307,seq22306__$1);
});

om_tools.dom.rt.cljs$lang$maxFixedArity = (1);

om_tools.dom.ruby = (function om_tools$dom$ruby(var_args){
var args22310 = [];
var len__5570__auto___22852 = arguments.length;
var i__5571__auto___22853 = (0);
while(true){
if((i__5571__auto___22853 < len__5570__auto___22852)){
args22310.push((arguments[i__5571__auto___22853]));

var G__22854 = (i__5571__auto___22853 + (1));
i__5571__auto___22853 = G__22854;
continue;
} else {
}
break;
}

var G__22314 = args22310.length;
switch (G__22314) {
case 0:
return om_tools.dom.ruby.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22310.slice((1)),(0)));
return om_tools.dom.ruby.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.ruby.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.ruby,null,null);
});

om_tools.dom.ruby.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.ruby,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.ruby.cljs$lang$applyTo = (function (seq22311){
var G__22312 = cljs.core.first(seq22311);
var seq22311__$1 = cljs.core.next(seq22311);
return om_tools.dom.ruby.cljs$core$IFn$_invoke$arity$variadic(G__22312,seq22311__$1);
});

om_tools.dom.ruby.cljs$lang$maxFixedArity = (1);

om_tools.dom.s = (function om_tools$dom$s(var_args){
var args22315 = [];
var len__5570__auto___22856 = arguments.length;
var i__5571__auto___22857 = (0);
while(true){
if((i__5571__auto___22857 < len__5570__auto___22856)){
args22315.push((arguments[i__5571__auto___22857]));

var G__22858 = (i__5571__auto___22857 + (1));
i__5571__auto___22857 = G__22858;
continue;
} else {
}
break;
}

var G__22319 = args22315.length;
switch (G__22319) {
case 0:
return om_tools.dom.s.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22315.slice((1)),(0)));
return om_tools.dom.s.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.s.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.s,null,null);
});

om_tools.dom.s.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.s,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.s.cljs$lang$applyTo = (function (seq22316){
var G__22317 = cljs.core.first(seq22316);
var seq22316__$1 = cljs.core.next(seq22316);
return om_tools.dom.s.cljs$core$IFn$_invoke$arity$variadic(G__22317,seq22316__$1);
});

om_tools.dom.s.cljs$lang$maxFixedArity = (1);

om_tools.dom.samp = (function om_tools$dom$samp(var_args){
var args22320 = [];
var len__5570__auto___22860 = arguments.length;
var i__5571__auto___22861 = (0);
while(true){
if((i__5571__auto___22861 < len__5570__auto___22860)){
args22320.push((arguments[i__5571__auto___22861]));

var G__22862 = (i__5571__auto___22861 + (1));
i__5571__auto___22861 = G__22862;
continue;
} else {
}
break;
}

var G__22324 = args22320.length;
switch (G__22324) {
case 0:
return om_tools.dom.samp.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22320.slice((1)),(0)));
return om_tools.dom.samp.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.samp.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.samp,null,null);
});

om_tools.dom.samp.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.samp,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.samp.cljs$lang$applyTo = (function (seq22321){
var G__22322 = cljs.core.first(seq22321);
var seq22321__$1 = cljs.core.next(seq22321);
return om_tools.dom.samp.cljs$core$IFn$_invoke$arity$variadic(G__22322,seq22321__$1);
});

om_tools.dom.samp.cljs$lang$maxFixedArity = (1);

om_tools.dom.script = (function om_tools$dom$script(var_args){
var args22325 = [];
var len__5570__auto___22864 = arguments.length;
var i__5571__auto___22865 = (0);
while(true){
if((i__5571__auto___22865 < len__5570__auto___22864)){
args22325.push((arguments[i__5571__auto___22865]));

var G__22866 = (i__5571__auto___22865 + (1));
i__5571__auto___22865 = G__22866;
continue;
} else {
}
break;
}

var G__22329 = args22325.length;
switch (G__22329) {
case 0:
return om_tools.dom.script.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22325.slice((1)),(0)));
return om_tools.dom.script.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.script.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.script,null,null);
});

om_tools.dom.script.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.script,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.script.cljs$lang$applyTo = (function (seq22326){
var G__22327 = cljs.core.first(seq22326);
var seq22326__$1 = cljs.core.next(seq22326);
return om_tools.dom.script.cljs$core$IFn$_invoke$arity$variadic(G__22327,seq22326__$1);
});

om_tools.dom.script.cljs$lang$maxFixedArity = (1);

om_tools.dom.section = (function om_tools$dom$section(var_args){
var args22330 = [];
var len__5570__auto___22868 = arguments.length;
var i__5571__auto___22869 = (0);
while(true){
if((i__5571__auto___22869 < len__5570__auto___22868)){
args22330.push((arguments[i__5571__auto___22869]));

var G__22870 = (i__5571__auto___22869 + (1));
i__5571__auto___22869 = G__22870;
continue;
} else {
}
break;
}

var G__22334 = args22330.length;
switch (G__22334) {
case 0:
return om_tools.dom.section.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22330.slice((1)),(0)));
return om_tools.dom.section.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.section.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.section,null,null);
});

om_tools.dom.section.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.section,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.section.cljs$lang$applyTo = (function (seq22331){
var G__22332 = cljs.core.first(seq22331);
var seq22331__$1 = cljs.core.next(seq22331);
return om_tools.dom.section.cljs$core$IFn$_invoke$arity$variadic(G__22332,seq22331__$1);
});

om_tools.dom.section.cljs$lang$maxFixedArity = (1);

om_tools.dom.select = (function om_tools$dom$select(var_args){
var args22335 = [];
var len__5570__auto___22872 = arguments.length;
var i__5571__auto___22873 = (0);
while(true){
if((i__5571__auto___22873 < len__5570__auto___22872)){
args22335.push((arguments[i__5571__auto___22873]));

var G__22874 = (i__5571__auto___22873 + (1));
i__5571__auto___22873 = G__22874;
continue;
} else {
}
break;
}

var G__22339 = args22335.length;
switch (G__22339) {
case 0:
return om_tools.dom.select.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22335.slice((1)),(0)));
return om_tools.dom.select.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.select.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.select,null,null);
});

om_tools.dom.select.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.select,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.select.cljs$lang$applyTo = (function (seq22336){
var G__22337 = cljs.core.first(seq22336);
var seq22336__$1 = cljs.core.next(seq22336);
return om_tools.dom.select.cljs$core$IFn$_invoke$arity$variadic(G__22337,seq22336__$1);
});

om_tools.dom.select.cljs$lang$maxFixedArity = (1);

om_tools.dom.small = (function om_tools$dom$small(var_args){
var args22340 = [];
var len__5570__auto___22876 = arguments.length;
var i__5571__auto___22877 = (0);
while(true){
if((i__5571__auto___22877 < len__5570__auto___22876)){
args22340.push((arguments[i__5571__auto___22877]));

var G__22878 = (i__5571__auto___22877 + (1));
i__5571__auto___22877 = G__22878;
continue;
} else {
}
break;
}

var G__22344 = args22340.length;
switch (G__22344) {
case 0:
return om_tools.dom.small.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22340.slice((1)),(0)));
return om_tools.dom.small.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.small.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.small,null,null);
});

om_tools.dom.small.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.small,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.small.cljs$lang$applyTo = (function (seq22341){
var G__22342 = cljs.core.first(seq22341);
var seq22341__$1 = cljs.core.next(seq22341);
return om_tools.dom.small.cljs$core$IFn$_invoke$arity$variadic(G__22342,seq22341__$1);
});

om_tools.dom.small.cljs$lang$maxFixedArity = (1);

om_tools.dom.source = (function om_tools$dom$source(var_args){
var args22345 = [];
var len__5570__auto___22880 = arguments.length;
var i__5571__auto___22881 = (0);
while(true){
if((i__5571__auto___22881 < len__5570__auto___22880)){
args22345.push((arguments[i__5571__auto___22881]));

var G__22882 = (i__5571__auto___22881 + (1));
i__5571__auto___22881 = G__22882;
continue;
} else {
}
break;
}

var G__22349 = args22345.length;
switch (G__22349) {
case 0:
return om_tools.dom.source.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22345.slice((1)),(0)));
return om_tools.dom.source.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.source.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.source,null,null);
});

om_tools.dom.source.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.source,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.source.cljs$lang$applyTo = (function (seq22346){
var G__22347 = cljs.core.first(seq22346);
var seq22346__$1 = cljs.core.next(seq22346);
return om_tools.dom.source.cljs$core$IFn$_invoke$arity$variadic(G__22347,seq22346__$1);
});

om_tools.dom.source.cljs$lang$maxFixedArity = (1);

om_tools.dom.span = (function om_tools$dom$span(var_args){
var args22350 = [];
var len__5570__auto___22884 = arguments.length;
var i__5571__auto___22885 = (0);
while(true){
if((i__5571__auto___22885 < len__5570__auto___22884)){
args22350.push((arguments[i__5571__auto___22885]));

var G__22886 = (i__5571__auto___22885 + (1));
i__5571__auto___22885 = G__22886;
continue;
} else {
}
break;
}

var G__22354 = args22350.length;
switch (G__22354) {
case 0:
return om_tools.dom.span.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22350.slice((1)),(0)));
return om_tools.dom.span.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.span.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.span,null,null);
});

om_tools.dom.span.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.span,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.span.cljs$lang$applyTo = (function (seq22351){
var G__22352 = cljs.core.first(seq22351);
var seq22351__$1 = cljs.core.next(seq22351);
return om_tools.dom.span.cljs$core$IFn$_invoke$arity$variadic(G__22352,seq22351__$1);
});

om_tools.dom.span.cljs$lang$maxFixedArity = (1);

om_tools.dom.strong = (function om_tools$dom$strong(var_args){
var args22355 = [];
var len__5570__auto___22888 = arguments.length;
var i__5571__auto___22889 = (0);
while(true){
if((i__5571__auto___22889 < len__5570__auto___22888)){
args22355.push((arguments[i__5571__auto___22889]));

var G__22890 = (i__5571__auto___22889 + (1));
i__5571__auto___22889 = G__22890;
continue;
} else {
}
break;
}

var G__22359 = args22355.length;
switch (G__22359) {
case 0:
return om_tools.dom.strong.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22355.slice((1)),(0)));
return om_tools.dom.strong.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.strong.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.strong,null,null);
});

om_tools.dom.strong.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.strong,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.strong.cljs$lang$applyTo = (function (seq22356){
var G__22357 = cljs.core.first(seq22356);
var seq22356__$1 = cljs.core.next(seq22356);
return om_tools.dom.strong.cljs$core$IFn$_invoke$arity$variadic(G__22357,seq22356__$1);
});

om_tools.dom.strong.cljs$lang$maxFixedArity = (1);

om_tools.dom.style = (function om_tools$dom$style(var_args){
var args22360 = [];
var len__5570__auto___22892 = arguments.length;
var i__5571__auto___22893 = (0);
while(true){
if((i__5571__auto___22893 < len__5570__auto___22892)){
args22360.push((arguments[i__5571__auto___22893]));

var G__22894 = (i__5571__auto___22893 + (1));
i__5571__auto___22893 = G__22894;
continue;
} else {
}
break;
}

var G__22364 = args22360.length;
switch (G__22364) {
case 0:
return om_tools.dom.style.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22360.slice((1)),(0)));
return om_tools.dom.style.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.style.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.style,null,null);
});

om_tools.dom.style.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.style,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.style.cljs$lang$applyTo = (function (seq22361){
var G__22362 = cljs.core.first(seq22361);
var seq22361__$1 = cljs.core.next(seq22361);
return om_tools.dom.style.cljs$core$IFn$_invoke$arity$variadic(G__22362,seq22361__$1);
});

om_tools.dom.style.cljs$lang$maxFixedArity = (1);

om_tools.dom.sub = (function om_tools$dom$sub(var_args){
var args22365 = [];
var len__5570__auto___22896 = arguments.length;
var i__5571__auto___22897 = (0);
while(true){
if((i__5571__auto___22897 < len__5570__auto___22896)){
args22365.push((arguments[i__5571__auto___22897]));

var G__22898 = (i__5571__auto___22897 + (1));
i__5571__auto___22897 = G__22898;
continue;
} else {
}
break;
}

var G__22369 = args22365.length;
switch (G__22369) {
case 0:
return om_tools.dom.sub.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22365.slice((1)),(0)));
return om_tools.dom.sub.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.sub.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.sub,null,null);
});

om_tools.dom.sub.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.sub,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.sub.cljs$lang$applyTo = (function (seq22366){
var G__22367 = cljs.core.first(seq22366);
var seq22366__$1 = cljs.core.next(seq22366);
return om_tools.dom.sub.cljs$core$IFn$_invoke$arity$variadic(G__22367,seq22366__$1);
});

om_tools.dom.sub.cljs$lang$maxFixedArity = (1);

om_tools.dom.summary = (function om_tools$dom$summary(var_args){
var args22370 = [];
var len__5570__auto___22900 = arguments.length;
var i__5571__auto___22901 = (0);
while(true){
if((i__5571__auto___22901 < len__5570__auto___22900)){
args22370.push((arguments[i__5571__auto___22901]));

var G__22902 = (i__5571__auto___22901 + (1));
i__5571__auto___22901 = G__22902;
continue;
} else {
}
break;
}

var G__22374 = args22370.length;
switch (G__22374) {
case 0:
return om_tools.dom.summary.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22370.slice((1)),(0)));
return om_tools.dom.summary.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.summary.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.summary,null,null);
});

om_tools.dom.summary.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.summary,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.summary.cljs$lang$applyTo = (function (seq22371){
var G__22372 = cljs.core.first(seq22371);
var seq22371__$1 = cljs.core.next(seq22371);
return om_tools.dom.summary.cljs$core$IFn$_invoke$arity$variadic(G__22372,seq22371__$1);
});

om_tools.dom.summary.cljs$lang$maxFixedArity = (1);

om_tools.dom.sup = (function om_tools$dom$sup(var_args){
var args22375 = [];
var len__5570__auto___22904 = arguments.length;
var i__5571__auto___22905 = (0);
while(true){
if((i__5571__auto___22905 < len__5570__auto___22904)){
args22375.push((arguments[i__5571__auto___22905]));

var G__22906 = (i__5571__auto___22905 + (1));
i__5571__auto___22905 = G__22906;
continue;
} else {
}
break;
}

var G__22379 = args22375.length;
switch (G__22379) {
case 0:
return om_tools.dom.sup.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22375.slice((1)),(0)));
return om_tools.dom.sup.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.sup.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.sup,null,null);
});

om_tools.dom.sup.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.sup,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.sup.cljs$lang$applyTo = (function (seq22376){
var G__22377 = cljs.core.first(seq22376);
var seq22376__$1 = cljs.core.next(seq22376);
return om_tools.dom.sup.cljs$core$IFn$_invoke$arity$variadic(G__22377,seq22376__$1);
});

om_tools.dom.sup.cljs$lang$maxFixedArity = (1);

om_tools.dom.table = (function om_tools$dom$table(var_args){
var args22380 = [];
var len__5570__auto___22908 = arguments.length;
var i__5571__auto___22909 = (0);
while(true){
if((i__5571__auto___22909 < len__5570__auto___22908)){
args22380.push((arguments[i__5571__auto___22909]));

var G__22910 = (i__5571__auto___22909 + (1));
i__5571__auto___22909 = G__22910;
continue;
} else {
}
break;
}

var G__22384 = args22380.length;
switch (G__22384) {
case 0:
return om_tools.dom.table.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22380.slice((1)),(0)));
return om_tools.dom.table.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.table.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.table,null,null);
});

om_tools.dom.table.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.table,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.table.cljs$lang$applyTo = (function (seq22381){
var G__22382 = cljs.core.first(seq22381);
var seq22381__$1 = cljs.core.next(seq22381);
return om_tools.dom.table.cljs$core$IFn$_invoke$arity$variadic(G__22382,seq22381__$1);
});

om_tools.dom.table.cljs$lang$maxFixedArity = (1);

om_tools.dom.tbody = (function om_tools$dom$tbody(var_args){
var args22385 = [];
var len__5570__auto___22912 = arguments.length;
var i__5571__auto___22913 = (0);
while(true){
if((i__5571__auto___22913 < len__5570__auto___22912)){
args22385.push((arguments[i__5571__auto___22913]));

var G__22914 = (i__5571__auto___22913 + (1));
i__5571__auto___22913 = G__22914;
continue;
} else {
}
break;
}

var G__22389 = args22385.length;
switch (G__22389) {
case 0:
return om_tools.dom.tbody.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22385.slice((1)),(0)));
return om_tools.dom.tbody.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.tbody.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.tbody,null,null);
});

om_tools.dom.tbody.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.tbody,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.tbody.cljs$lang$applyTo = (function (seq22386){
var G__22387 = cljs.core.first(seq22386);
var seq22386__$1 = cljs.core.next(seq22386);
return om_tools.dom.tbody.cljs$core$IFn$_invoke$arity$variadic(G__22387,seq22386__$1);
});

om_tools.dom.tbody.cljs$lang$maxFixedArity = (1);

om_tools.dom.td = (function om_tools$dom$td(var_args){
var args22390 = [];
var len__5570__auto___22916 = arguments.length;
var i__5571__auto___22917 = (0);
while(true){
if((i__5571__auto___22917 < len__5570__auto___22916)){
args22390.push((arguments[i__5571__auto___22917]));

var G__22918 = (i__5571__auto___22917 + (1));
i__5571__auto___22917 = G__22918;
continue;
} else {
}
break;
}

var G__22394 = args22390.length;
switch (G__22394) {
case 0:
return om_tools.dom.td.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22390.slice((1)),(0)));
return om_tools.dom.td.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.td.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.td,null,null);
});

om_tools.dom.td.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.td,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.td.cljs$lang$applyTo = (function (seq22391){
var G__22392 = cljs.core.first(seq22391);
var seq22391__$1 = cljs.core.next(seq22391);
return om_tools.dom.td.cljs$core$IFn$_invoke$arity$variadic(G__22392,seq22391__$1);
});

om_tools.dom.td.cljs$lang$maxFixedArity = (1);

om_tools.dom.tfoot = (function om_tools$dom$tfoot(var_args){
var args22395 = [];
var len__5570__auto___22920 = arguments.length;
var i__5571__auto___22921 = (0);
while(true){
if((i__5571__auto___22921 < len__5570__auto___22920)){
args22395.push((arguments[i__5571__auto___22921]));

var G__22922 = (i__5571__auto___22921 + (1));
i__5571__auto___22921 = G__22922;
continue;
} else {
}
break;
}

var G__22399 = args22395.length;
switch (G__22399) {
case 0:
return om_tools.dom.tfoot.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22395.slice((1)),(0)));
return om_tools.dom.tfoot.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.tfoot.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.tfoot,null,null);
});

om_tools.dom.tfoot.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.tfoot,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.tfoot.cljs$lang$applyTo = (function (seq22396){
var G__22397 = cljs.core.first(seq22396);
var seq22396__$1 = cljs.core.next(seq22396);
return om_tools.dom.tfoot.cljs$core$IFn$_invoke$arity$variadic(G__22397,seq22396__$1);
});

om_tools.dom.tfoot.cljs$lang$maxFixedArity = (1);

om_tools.dom.th = (function om_tools$dom$th(var_args){
var args22400 = [];
var len__5570__auto___22924 = arguments.length;
var i__5571__auto___22925 = (0);
while(true){
if((i__5571__auto___22925 < len__5570__auto___22924)){
args22400.push((arguments[i__5571__auto___22925]));

var G__22926 = (i__5571__auto___22925 + (1));
i__5571__auto___22925 = G__22926;
continue;
} else {
}
break;
}

var G__22404 = args22400.length;
switch (G__22404) {
case 0:
return om_tools.dom.th.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22400.slice((1)),(0)));
return om_tools.dom.th.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.th.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.th,null,null);
});

om_tools.dom.th.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.th,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.th.cljs$lang$applyTo = (function (seq22401){
var G__22402 = cljs.core.first(seq22401);
var seq22401__$1 = cljs.core.next(seq22401);
return om_tools.dom.th.cljs$core$IFn$_invoke$arity$variadic(G__22402,seq22401__$1);
});

om_tools.dom.th.cljs$lang$maxFixedArity = (1);

om_tools.dom.thead = (function om_tools$dom$thead(var_args){
var args22405 = [];
var len__5570__auto___22928 = arguments.length;
var i__5571__auto___22929 = (0);
while(true){
if((i__5571__auto___22929 < len__5570__auto___22928)){
args22405.push((arguments[i__5571__auto___22929]));

var G__22930 = (i__5571__auto___22929 + (1));
i__5571__auto___22929 = G__22930;
continue;
} else {
}
break;
}

var G__22409 = args22405.length;
switch (G__22409) {
case 0:
return om_tools.dom.thead.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22405.slice((1)),(0)));
return om_tools.dom.thead.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.thead.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.thead,null,null);
});

om_tools.dom.thead.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.thead,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.thead.cljs$lang$applyTo = (function (seq22406){
var G__22407 = cljs.core.first(seq22406);
var seq22406__$1 = cljs.core.next(seq22406);
return om_tools.dom.thead.cljs$core$IFn$_invoke$arity$variadic(G__22407,seq22406__$1);
});

om_tools.dom.thead.cljs$lang$maxFixedArity = (1);

om_tools.dom.time = (function om_tools$dom$time(var_args){
var args22410 = [];
var len__5570__auto___22932 = arguments.length;
var i__5571__auto___22933 = (0);
while(true){
if((i__5571__auto___22933 < len__5570__auto___22932)){
args22410.push((arguments[i__5571__auto___22933]));

var G__22934 = (i__5571__auto___22933 + (1));
i__5571__auto___22933 = G__22934;
continue;
} else {
}
break;
}

var G__22414 = args22410.length;
switch (G__22414) {
case 0:
return om_tools.dom.time.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22410.slice((1)),(0)));
return om_tools.dom.time.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.time.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.time,null,null);
});

om_tools.dom.time.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.time,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.time.cljs$lang$applyTo = (function (seq22411){
var G__22412 = cljs.core.first(seq22411);
var seq22411__$1 = cljs.core.next(seq22411);
return om_tools.dom.time.cljs$core$IFn$_invoke$arity$variadic(G__22412,seq22411__$1);
});

om_tools.dom.time.cljs$lang$maxFixedArity = (1);

om_tools.dom.title = (function om_tools$dom$title(var_args){
var args22415 = [];
var len__5570__auto___22936 = arguments.length;
var i__5571__auto___22937 = (0);
while(true){
if((i__5571__auto___22937 < len__5570__auto___22936)){
args22415.push((arguments[i__5571__auto___22937]));

var G__22938 = (i__5571__auto___22937 + (1));
i__5571__auto___22937 = G__22938;
continue;
} else {
}
break;
}

var G__22419 = args22415.length;
switch (G__22419) {
case 0:
return om_tools.dom.title.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22415.slice((1)),(0)));
return om_tools.dom.title.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.title.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.title,null,null);
});

om_tools.dom.title.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.title,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.title.cljs$lang$applyTo = (function (seq22416){
var G__22417 = cljs.core.first(seq22416);
var seq22416__$1 = cljs.core.next(seq22416);
return om_tools.dom.title.cljs$core$IFn$_invoke$arity$variadic(G__22417,seq22416__$1);
});

om_tools.dom.title.cljs$lang$maxFixedArity = (1);

om_tools.dom.tr = (function om_tools$dom$tr(var_args){
var args22420 = [];
var len__5570__auto___22940 = arguments.length;
var i__5571__auto___22941 = (0);
while(true){
if((i__5571__auto___22941 < len__5570__auto___22940)){
args22420.push((arguments[i__5571__auto___22941]));

var G__22942 = (i__5571__auto___22941 + (1));
i__5571__auto___22941 = G__22942;
continue;
} else {
}
break;
}

var G__22424 = args22420.length;
switch (G__22424) {
case 0:
return om_tools.dom.tr.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22420.slice((1)),(0)));
return om_tools.dom.tr.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.tr.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.tr,null,null);
});

om_tools.dom.tr.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.tr,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.tr.cljs$lang$applyTo = (function (seq22421){
var G__22422 = cljs.core.first(seq22421);
var seq22421__$1 = cljs.core.next(seq22421);
return om_tools.dom.tr.cljs$core$IFn$_invoke$arity$variadic(G__22422,seq22421__$1);
});

om_tools.dom.tr.cljs$lang$maxFixedArity = (1);

om_tools.dom.track = (function om_tools$dom$track(var_args){
var args22425 = [];
var len__5570__auto___22944 = arguments.length;
var i__5571__auto___22945 = (0);
while(true){
if((i__5571__auto___22945 < len__5570__auto___22944)){
args22425.push((arguments[i__5571__auto___22945]));

var G__22946 = (i__5571__auto___22945 + (1));
i__5571__auto___22945 = G__22946;
continue;
} else {
}
break;
}

var G__22429 = args22425.length;
switch (G__22429) {
case 0:
return om_tools.dom.track.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22425.slice((1)),(0)));
return om_tools.dom.track.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.track.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.track,null,null);
});

om_tools.dom.track.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.track,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.track.cljs$lang$applyTo = (function (seq22426){
var G__22427 = cljs.core.first(seq22426);
var seq22426__$1 = cljs.core.next(seq22426);
return om_tools.dom.track.cljs$core$IFn$_invoke$arity$variadic(G__22427,seq22426__$1);
});

om_tools.dom.track.cljs$lang$maxFixedArity = (1);

om_tools.dom.u = (function om_tools$dom$u(var_args){
var args22430 = [];
var len__5570__auto___22948 = arguments.length;
var i__5571__auto___22949 = (0);
while(true){
if((i__5571__auto___22949 < len__5570__auto___22948)){
args22430.push((arguments[i__5571__auto___22949]));

var G__22950 = (i__5571__auto___22949 + (1));
i__5571__auto___22949 = G__22950;
continue;
} else {
}
break;
}

var G__22434 = args22430.length;
switch (G__22434) {
case 0:
return om_tools.dom.u.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22430.slice((1)),(0)));
return om_tools.dom.u.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.u.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.u,null,null);
});

om_tools.dom.u.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.u,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.u.cljs$lang$applyTo = (function (seq22431){
var G__22432 = cljs.core.first(seq22431);
var seq22431__$1 = cljs.core.next(seq22431);
return om_tools.dom.u.cljs$core$IFn$_invoke$arity$variadic(G__22432,seq22431__$1);
});

om_tools.dom.u.cljs$lang$maxFixedArity = (1);

om_tools.dom.ul = (function om_tools$dom$ul(var_args){
var args22435 = [];
var len__5570__auto___22952 = arguments.length;
var i__5571__auto___22953 = (0);
while(true){
if((i__5571__auto___22953 < len__5570__auto___22952)){
args22435.push((arguments[i__5571__auto___22953]));

var G__22954 = (i__5571__auto___22953 + (1));
i__5571__auto___22953 = G__22954;
continue;
} else {
}
break;
}

var G__22439 = args22435.length;
switch (G__22439) {
case 0:
return om_tools.dom.ul.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22435.slice((1)),(0)));
return om_tools.dom.ul.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.ul.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.ul,null,null);
});

om_tools.dom.ul.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.ul,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.ul.cljs$lang$applyTo = (function (seq22436){
var G__22437 = cljs.core.first(seq22436);
var seq22436__$1 = cljs.core.next(seq22436);
return om_tools.dom.ul.cljs$core$IFn$_invoke$arity$variadic(G__22437,seq22436__$1);
});

om_tools.dom.ul.cljs$lang$maxFixedArity = (1);

om_tools.dom.var$ = (function om_tools$dom$var(var_args){
var args22440 = [];
var len__5570__auto___22956 = arguments.length;
var i__5571__auto___22957 = (0);
while(true){
if((i__5571__auto___22957 < len__5570__auto___22956)){
args22440.push((arguments[i__5571__auto___22957]));

var G__22958 = (i__5571__auto___22957 + (1));
i__5571__auto___22957 = G__22958;
continue;
} else {
}
break;
}

var G__22444 = args22440.length;
switch (G__22444) {
case 0:
return om_tools.dom.var$.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22440.slice((1)),(0)));
return om_tools.dom.var$.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.var$.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.var$,null,null);
});

om_tools.dom.var$.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.var$,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.var$.cljs$lang$applyTo = (function (seq22441){
var G__22442 = cljs.core.first(seq22441);
var seq22441__$1 = cljs.core.next(seq22441);
return om_tools.dom.var$.cljs$core$IFn$_invoke$arity$variadic(G__22442,seq22441__$1);
});

om_tools.dom.var$.cljs$lang$maxFixedArity = (1);

om_tools.dom.video = (function om_tools$dom$video(var_args){
var args22445 = [];
var len__5570__auto___22960 = arguments.length;
var i__5571__auto___22961 = (0);
while(true){
if((i__5571__auto___22961 < len__5570__auto___22960)){
args22445.push((arguments[i__5571__auto___22961]));

var G__22962 = (i__5571__auto___22961 + (1));
i__5571__auto___22961 = G__22962;
continue;
} else {
}
break;
}

var G__22449 = args22445.length;
switch (G__22449) {
case 0:
return om_tools.dom.video.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22445.slice((1)),(0)));
return om_tools.dom.video.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.video.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.video,null,null);
});

om_tools.dom.video.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.video,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.video.cljs$lang$applyTo = (function (seq22446){
var G__22447 = cljs.core.first(seq22446);
var seq22446__$1 = cljs.core.next(seq22446);
return om_tools.dom.video.cljs$core$IFn$_invoke$arity$variadic(G__22447,seq22446__$1);
});

om_tools.dom.video.cljs$lang$maxFixedArity = (1);

om_tools.dom.wbr = (function om_tools$dom$wbr(var_args){
var args22450 = [];
var len__5570__auto___22964 = arguments.length;
var i__5571__auto___22965 = (0);
while(true){
if((i__5571__auto___22965 < len__5570__auto___22964)){
args22450.push((arguments[i__5571__auto___22965]));

var G__22966 = (i__5571__auto___22965 + (1));
i__5571__auto___22965 = G__22966;
continue;
} else {
}
break;
}

var G__22454 = args22450.length;
switch (G__22454) {
case 0:
return om_tools.dom.wbr.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22450.slice((1)),(0)));
return om_tools.dom.wbr.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.wbr.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.wbr,null,null);
});

om_tools.dom.wbr.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.wbr,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.wbr.cljs$lang$applyTo = (function (seq22451){
var G__22452 = cljs.core.first(seq22451);
var seq22451__$1 = cljs.core.next(seq22451);
return om_tools.dom.wbr.cljs$core$IFn$_invoke$arity$variadic(G__22452,seq22451__$1);
});

om_tools.dom.wbr.cljs$lang$maxFixedArity = (1);

om_tools.dom.circle = (function om_tools$dom$circle(var_args){
var args22455 = [];
var len__5570__auto___22968 = arguments.length;
var i__5571__auto___22969 = (0);
while(true){
if((i__5571__auto___22969 < len__5570__auto___22968)){
args22455.push((arguments[i__5571__auto___22969]));

var G__22970 = (i__5571__auto___22969 + (1));
i__5571__auto___22969 = G__22970;
continue;
} else {
}
break;
}

var G__22459 = args22455.length;
switch (G__22459) {
case 0:
return om_tools.dom.circle.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22455.slice((1)),(0)));
return om_tools.dom.circle.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.circle.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.circle,null,null);
});

om_tools.dom.circle.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.circle,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.circle.cljs$lang$applyTo = (function (seq22456){
var G__22457 = cljs.core.first(seq22456);
var seq22456__$1 = cljs.core.next(seq22456);
return om_tools.dom.circle.cljs$core$IFn$_invoke$arity$variadic(G__22457,seq22456__$1);
});

om_tools.dom.circle.cljs$lang$maxFixedArity = (1);

om_tools.dom.ellipse = (function om_tools$dom$ellipse(var_args){
var args22460 = [];
var len__5570__auto___22972 = arguments.length;
var i__5571__auto___22973 = (0);
while(true){
if((i__5571__auto___22973 < len__5570__auto___22972)){
args22460.push((arguments[i__5571__auto___22973]));

var G__22974 = (i__5571__auto___22973 + (1));
i__5571__auto___22973 = G__22974;
continue;
} else {
}
break;
}

var G__22464 = args22460.length;
switch (G__22464) {
case 0:
return om_tools.dom.ellipse.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22460.slice((1)),(0)));
return om_tools.dom.ellipse.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.ellipse.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.ellipse,null,null);
});

om_tools.dom.ellipse.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.ellipse,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.ellipse.cljs$lang$applyTo = (function (seq22461){
var G__22462 = cljs.core.first(seq22461);
var seq22461__$1 = cljs.core.next(seq22461);
return om_tools.dom.ellipse.cljs$core$IFn$_invoke$arity$variadic(G__22462,seq22461__$1);
});

om_tools.dom.ellipse.cljs$lang$maxFixedArity = (1);

om_tools.dom.g = (function om_tools$dom$g(var_args){
var args22465 = [];
var len__5570__auto___22976 = arguments.length;
var i__5571__auto___22977 = (0);
while(true){
if((i__5571__auto___22977 < len__5570__auto___22976)){
args22465.push((arguments[i__5571__auto___22977]));

var G__22978 = (i__5571__auto___22977 + (1));
i__5571__auto___22977 = G__22978;
continue;
} else {
}
break;
}

var G__22469 = args22465.length;
switch (G__22469) {
case 0:
return om_tools.dom.g.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22465.slice((1)),(0)));
return om_tools.dom.g.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.g.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.g,null,null);
});

om_tools.dom.g.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.g,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.g.cljs$lang$applyTo = (function (seq22466){
var G__22467 = cljs.core.first(seq22466);
var seq22466__$1 = cljs.core.next(seq22466);
return om_tools.dom.g.cljs$core$IFn$_invoke$arity$variadic(G__22467,seq22466__$1);
});

om_tools.dom.g.cljs$lang$maxFixedArity = (1);

om_tools.dom.line = (function om_tools$dom$line(var_args){
var args22470 = [];
var len__5570__auto___22980 = arguments.length;
var i__5571__auto___22981 = (0);
while(true){
if((i__5571__auto___22981 < len__5570__auto___22980)){
args22470.push((arguments[i__5571__auto___22981]));

var G__22982 = (i__5571__auto___22981 + (1));
i__5571__auto___22981 = G__22982;
continue;
} else {
}
break;
}

var G__22474 = args22470.length;
switch (G__22474) {
case 0:
return om_tools.dom.line.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22470.slice((1)),(0)));
return om_tools.dom.line.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.line.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.line,null,null);
});

om_tools.dom.line.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.line,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.line.cljs$lang$applyTo = (function (seq22471){
var G__22472 = cljs.core.first(seq22471);
var seq22471__$1 = cljs.core.next(seq22471);
return om_tools.dom.line.cljs$core$IFn$_invoke$arity$variadic(G__22472,seq22471__$1);
});

om_tools.dom.line.cljs$lang$maxFixedArity = (1);

om_tools.dom.path = (function om_tools$dom$path(var_args){
var args22475 = [];
var len__5570__auto___22984 = arguments.length;
var i__5571__auto___22985 = (0);
while(true){
if((i__5571__auto___22985 < len__5570__auto___22984)){
args22475.push((arguments[i__5571__auto___22985]));

var G__22986 = (i__5571__auto___22985 + (1));
i__5571__auto___22985 = G__22986;
continue;
} else {
}
break;
}

var G__22479 = args22475.length;
switch (G__22479) {
case 0:
return om_tools.dom.path.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22475.slice((1)),(0)));
return om_tools.dom.path.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.path.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.path,null,null);
});

om_tools.dom.path.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.path,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.path.cljs$lang$applyTo = (function (seq22476){
var G__22477 = cljs.core.first(seq22476);
var seq22476__$1 = cljs.core.next(seq22476);
return om_tools.dom.path.cljs$core$IFn$_invoke$arity$variadic(G__22477,seq22476__$1);
});

om_tools.dom.path.cljs$lang$maxFixedArity = (1);

om_tools.dom.polyline = (function om_tools$dom$polyline(var_args){
var args22480 = [];
var len__5570__auto___22988 = arguments.length;
var i__5571__auto___22989 = (0);
while(true){
if((i__5571__auto___22989 < len__5570__auto___22988)){
args22480.push((arguments[i__5571__auto___22989]));

var G__22990 = (i__5571__auto___22989 + (1));
i__5571__auto___22989 = G__22990;
continue;
} else {
}
break;
}

var G__22484 = args22480.length;
switch (G__22484) {
case 0:
return om_tools.dom.polyline.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22480.slice((1)),(0)));
return om_tools.dom.polyline.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.polyline.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.polyline,null,null);
});

om_tools.dom.polyline.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.polyline,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.polyline.cljs$lang$applyTo = (function (seq22481){
var G__22482 = cljs.core.first(seq22481);
var seq22481__$1 = cljs.core.next(seq22481);
return om_tools.dom.polyline.cljs$core$IFn$_invoke$arity$variadic(G__22482,seq22481__$1);
});

om_tools.dom.polyline.cljs$lang$maxFixedArity = (1);

om_tools.dom.rect = (function om_tools$dom$rect(var_args){
var args22485 = [];
var len__5570__auto___22992 = arguments.length;
var i__5571__auto___22993 = (0);
while(true){
if((i__5571__auto___22993 < len__5570__auto___22992)){
args22485.push((arguments[i__5571__auto___22993]));

var G__22994 = (i__5571__auto___22993 + (1));
i__5571__auto___22993 = G__22994;
continue;
} else {
}
break;
}

var G__22489 = args22485.length;
switch (G__22489) {
case 0:
return om_tools.dom.rect.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22485.slice((1)),(0)));
return om_tools.dom.rect.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.rect.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.rect,null,null);
});

om_tools.dom.rect.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.rect,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.rect.cljs$lang$applyTo = (function (seq22486){
var G__22487 = cljs.core.first(seq22486);
var seq22486__$1 = cljs.core.next(seq22486);
return om_tools.dom.rect.cljs$core$IFn$_invoke$arity$variadic(G__22487,seq22486__$1);
});

om_tools.dom.rect.cljs$lang$maxFixedArity = (1);

om_tools.dom.svg = (function om_tools$dom$svg(var_args){
var args22490 = [];
var len__5570__auto___22996 = arguments.length;
var i__5571__auto___22997 = (0);
while(true){
if((i__5571__auto___22997 < len__5570__auto___22996)){
args22490.push((arguments[i__5571__auto___22997]));

var G__22998 = (i__5571__auto___22997 + (1));
i__5571__auto___22997 = G__22998;
continue;
} else {
}
break;
}

var G__22494 = args22490.length;
switch (G__22494) {
case 0:
return om_tools.dom.svg.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22490.slice((1)),(0)));
return om_tools.dom.svg.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.svg.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.svg,null,null);
});

om_tools.dom.svg.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.svg,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.svg.cljs$lang$applyTo = (function (seq22491){
var G__22492 = cljs.core.first(seq22491);
var seq22491__$1 = cljs.core.next(seq22491);
return om_tools.dom.svg.cljs$core$IFn$_invoke$arity$variadic(G__22492,seq22491__$1);
});

om_tools.dom.svg.cljs$lang$maxFixedArity = (1);

om_tools.dom.text = (function om_tools$dom$text(var_args){
var args22495 = [];
var len__5570__auto___23000 = arguments.length;
var i__5571__auto___23001 = (0);
while(true){
if((i__5571__auto___23001 < len__5570__auto___23000)){
args22495.push((arguments[i__5571__auto___23001]));

var G__23002 = (i__5571__auto___23001 + (1));
i__5571__auto___23001 = G__23002;
continue;
} else {
}
break;
}

var G__22499 = args22495.length;
switch (G__22499) {
case 0:
return om_tools.dom.text.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22495.slice((1)),(0)));
return om_tools.dom.text.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.text.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.text,null,null);
});

om_tools.dom.text.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.text,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.text.cljs$lang$applyTo = (function (seq22496){
var G__22497 = cljs.core.first(seq22496);
var seq22496__$1 = cljs.core.next(seq22496);
return om_tools.dom.text.cljs$core$IFn$_invoke$arity$variadic(G__22497,seq22496__$1);
});

om_tools.dom.text.cljs$lang$maxFixedArity = (1);

om_tools.dom.defs = (function om_tools$dom$defs(var_args){
var args22500 = [];
var len__5570__auto___23004 = arguments.length;
var i__5571__auto___23005 = (0);
while(true){
if((i__5571__auto___23005 < len__5570__auto___23004)){
args22500.push((arguments[i__5571__auto___23005]));

var G__23006 = (i__5571__auto___23005 + (1));
i__5571__auto___23005 = G__23006;
continue;
} else {
}
break;
}

var G__22504 = args22500.length;
switch (G__22504) {
case 0:
return om_tools.dom.defs.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22500.slice((1)),(0)));
return om_tools.dom.defs.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.defs.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.defs,null,null);
});

om_tools.dom.defs.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.defs,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.defs.cljs$lang$applyTo = (function (seq22501){
var G__22502 = cljs.core.first(seq22501);
var seq22501__$1 = cljs.core.next(seq22501);
return om_tools.dom.defs.cljs$core$IFn$_invoke$arity$variadic(G__22502,seq22501__$1);
});

om_tools.dom.defs.cljs$lang$maxFixedArity = (1);

om_tools.dom.linearGradient = (function om_tools$dom$linearGradient(var_args){
var args22505 = [];
var len__5570__auto___23008 = arguments.length;
var i__5571__auto___23009 = (0);
while(true){
if((i__5571__auto___23009 < len__5570__auto___23008)){
args22505.push((arguments[i__5571__auto___23009]));

var G__23010 = (i__5571__auto___23009 + (1));
i__5571__auto___23009 = G__23010;
continue;
} else {
}
break;
}

var G__22509 = args22505.length;
switch (G__22509) {
case 0:
return om_tools.dom.linearGradient.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22505.slice((1)),(0)));
return om_tools.dom.linearGradient.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.linearGradient.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.linearGradient,null,null);
});

om_tools.dom.linearGradient.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.linearGradient,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.linearGradient.cljs$lang$applyTo = (function (seq22506){
var G__22507 = cljs.core.first(seq22506);
var seq22506__$1 = cljs.core.next(seq22506);
return om_tools.dom.linearGradient.cljs$core$IFn$_invoke$arity$variadic(G__22507,seq22506__$1);
});

om_tools.dom.linearGradient.cljs$lang$maxFixedArity = (1);

om_tools.dom.polygon = (function om_tools$dom$polygon(var_args){
var args22510 = [];
var len__5570__auto___23012 = arguments.length;
var i__5571__auto___23013 = (0);
while(true){
if((i__5571__auto___23013 < len__5570__auto___23012)){
args22510.push((arguments[i__5571__auto___23013]));

var G__23014 = (i__5571__auto___23013 + (1));
i__5571__auto___23013 = G__23014;
continue;
} else {
}
break;
}

var G__22514 = args22510.length;
switch (G__22514) {
case 0:
return om_tools.dom.polygon.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22510.slice((1)),(0)));
return om_tools.dom.polygon.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.polygon.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.polygon,null,null);
});

om_tools.dom.polygon.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.polygon,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.polygon.cljs$lang$applyTo = (function (seq22511){
var G__22512 = cljs.core.first(seq22511);
var seq22511__$1 = cljs.core.next(seq22511);
return om_tools.dom.polygon.cljs$core$IFn$_invoke$arity$variadic(G__22512,seq22511__$1);
});

om_tools.dom.polygon.cljs$lang$maxFixedArity = (1);

om_tools.dom.radialGradient = (function om_tools$dom$radialGradient(var_args){
var args22515 = [];
var len__5570__auto___23016 = arguments.length;
var i__5571__auto___23017 = (0);
while(true){
if((i__5571__auto___23017 < len__5570__auto___23016)){
args22515.push((arguments[i__5571__auto___23017]));

var G__23018 = (i__5571__auto___23017 + (1));
i__5571__auto___23017 = G__23018;
continue;
} else {
}
break;
}

var G__22519 = args22515.length;
switch (G__22519) {
case 0:
return om_tools.dom.radialGradient.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22515.slice((1)),(0)));
return om_tools.dom.radialGradient.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.radialGradient.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.radialGradient,null,null);
});

om_tools.dom.radialGradient.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.radialGradient,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.radialGradient.cljs$lang$applyTo = (function (seq22516){
var G__22517 = cljs.core.first(seq22516);
var seq22516__$1 = cljs.core.next(seq22516);
return om_tools.dom.radialGradient.cljs$core$IFn$_invoke$arity$variadic(G__22517,seq22516__$1);
});

om_tools.dom.radialGradient.cljs$lang$maxFixedArity = (1);

om_tools.dom.stop = (function om_tools$dom$stop(var_args){
var args22520 = [];
var len__5570__auto___23020 = arguments.length;
var i__5571__auto___23021 = (0);
while(true){
if((i__5571__auto___23021 < len__5570__auto___23020)){
args22520.push((arguments[i__5571__auto___23021]));

var G__23022 = (i__5571__auto___23021 + (1));
i__5571__auto___23021 = G__23022;
continue;
} else {
}
break;
}

var G__22524 = args22520.length;
switch (G__22524) {
case 0:
return om_tools.dom.stop.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22520.slice((1)),(0)));
return om_tools.dom.stop.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.stop.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.stop,null,null);
});

om_tools.dom.stop.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.stop,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.stop.cljs$lang$applyTo = (function (seq22521){
var G__22522 = cljs.core.first(seq22521);
var seq22521__$1 = cljs.core.next(seq22521);
return om_tools.dom.stop.cljs$core$IFn$_invoke$arity$variadic(G__22522,seq22521__$1);
});

om_tools.dom.stop.cljs$lang$maxFixedArity = (1);

om_tools.dom.tspan = (function om_tools$dom$tspan(var_args){
var args22525 = [];
var len__5570__auto___23024 = arguments.length;
var i__5571__auto___23025 = (0);
while(true){
if((i__5571__auto___23025 < len__5570__auto___23024)){
args22525.push((arguments[i__5571__auto___23025]));

var G__23026 = (i__5571__auto___23025 + (1));
i__5571__auto___23025 = G__23026;
continue;
} else {
}
break;
}

var G__22529 = args22525.length;
switch (G__22529) {
case 0:
return om_tools.dom.tspan.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22525.slice((1)),(0)));
return om_tools.dom.tspan.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.tspan.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(React.DOM.tspan,null,null);
});

om_tools.dom.tspan.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(React.DOM.tspan,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.tspan.cljs$lang$applyTo = (function (seq22526){
var G__22527 = cljs.core.first(seq22526);
var seq22526__$1 = cljs.core.next(seq22526);
return om_tools.dom.tspan.cljs$core$IFn$_invoke$arity$variadic(G__22527,seq22526__$1);
});

om_tools.dom.tspan.cljs$lang$maxFixedArity = (1);

om_tools.dom.input = (function om_tools$dom$input(var_args){
var args22530 = [];
var len__5570__auto___23028 = arguments.length;
var i__5571__auto___23029 = (0);
while(true){
if((i__5571__auto___23029 < len__5570__auto___23028)){
args22530.push((arguments[i__5571__auto___23029]));

var G__23030 = (i__5571__auto___23029 + (1));
i__5571__auto___23029 = G__23030;
continue;
} else {
}
break;
}

var G__22534 = args22530.length;
switch (G__22534) {
case 0:
return om_tools.dom.input.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22530.slice((1)),(0)));
return om_tools.dom.input.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.input.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(om.dom.input,null,null);
});

om_tools.dom.input.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(om.dom.input,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.input.cljs$lang$applyTo = (function (seq22531){
var G__22532 = cljs.core.first(seq22531);
var seq22531__$1 = cljs.core.next(seq22531);
return om_tools.dom.input.cljs$core$IFn$_invoke$arity$variadic(G__22532,seq22531__$1);
});

om_tools.dom.input.cljs$lang$maxFixedArity = (1);

om_tools.dom.textarea = (function om_tools$dom$textarea(var_args){
var args22535 = [];
var len__5570__auto___23032 = arguments.length;
var i__5571__auto___23033 = (0);
while(true){
if((i__5571__auto___23033 < len__5570__auto___23032)){
args22535.push((arguments[i__5571__auto___23033]));

var G__23034 = (i__5571__auto___23033 + (1));
i__5571__auto___23033 = G__23034;
continue;
} else {
}
break;
}

var G__22539 = args22535.length;
switch (G__22539) {
case 0:
return om_tools.dom.textarea.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22535.slice((1)),(0)));
return om_tools.dom.textarea.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.textarea.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(om.dom.textarea,null,null);
});

om_tools.dom.textarea.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(om.dom.textarea,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.textarea.cljs$lang$applyTo = (function (seq22536){
var G__22537 = cljs.core.first(seq22536);
var seq22536__$1 = cljs.core.next(seq22536);
return om_tools.dom.textarea.cljs$core$IFn$_invoke$arity$variadic(G__22537,seq22536__$1);
});

om_tools.dom.textarea.cljs$lang$maxFixedArity = (1);

om_tools.dom.option = (function om_tools$dom$option(var_args){
var args22075 = [];
var len__5570__auto___23036 = arguments.length;
var i__5571__auto___23037 = (0);
while(true){
if((i__5571__auto___23037 < len__5570__auto___23036)){
args22075.push((arguments[i__5571__auto___23037]));

var G__23038 = (i__5571__auto___23037 + (1));
i__5571__auto___23037 = G__23038;
continue;
} else {
}
break;
}

var G__22079 = args22075.length;
switch (G__22079) {
case 0:
return om_tools.dom.option.cljs$core$IFn$_invoke$arity$0();

break;
default:
var argseq__5589__auto__ = (new cljs.core.IndexedSeq(args22075.slice((1)),(0)));
return om_tools.dom.option.cljs$core$IFn$_invoke$arity$variadic((arguments[(0)]),argseq__5589__auto__);

}
});

om_tools.dom.option.cljs$core$IFn$_invoke$arity$0 = (function (){
return om_tools.dom.element(om.dom.option,null,null);
});

om_tools.dom.option.cljs$core$IFn$_invoke$arity$variadic = (function (opts__11517__auto__,children__11518__auto__){
return om_tools.dom.element(om.dom.option,opts__11517__auto__,children__11518__auto__);
});

om_tools.dom.option.cljs$lang$applyTo = (function (seq22076){
var G__22077 = cljs.core.first(seq22076);
var seq22076__$1 = cljs.core.next(seq22076);
return om_tools.dom.option.cljs$core$IFn$_invoke$arity$variadic(G__22077,seq22076__$1);
});

om_tools.dom.option.cljs$lang$maxFixedArity = (1);
om_tools.dom.class_set = (function om_tools$dom$class_set(m){

var temp__4425__auto__ = cljs.core.seq(cljs.core.distinct.cljs$core$IFn$_invoke$arity$1(cljs.core.map.cljs$core$IFn$_invoke$arity$2(cljs.core.name,cljs.core.keys(cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.val,m)))));
if(temp__4425__auto__){
var ks = temp__4425__auto__;
return clojure.string.join.cljs$core$IFn$_invoke$arity$2(" ",ks);
} else {
return null;
}
});
